Change Log
============

5.0.0 - June 3, 2025
----------
* Includes all changes from `5.0.0-beta` and `5.0.0-rc` releases.

Bug Fixes:
* `Multiselect` without `compact` no longer scrolls unnecessarily when more `Options` are added (SUI-7821).
* `ControlGroup` no longer appears disabled if any child has `disabled="dimmed"`; all children need to have `disabled={true}` for the group to appear disabled (SUI-7701).
* `ControlGroup`'s label will no longer render as disabled when there are enabled or dimmed children (SUI-7701).
* `Modal` `Popover`, and `TransitionOpen` will now properly be removed from the DOM on close when using `React.StrictMode` under React 18 (SUI-7469).
* `Message` no longer has extra spacing in the content when there's no remove button (SUI-7790).
* `Select` now has a consistent NVDA and VO screen reader announcements (A11Y-2965).

5.0.0-rc.2 - May 28, 2025
----------
New Features:
* `Code` now supports `language="sql"` (SUI-7614).
* `Table.HeadCell` now supports the `tooltip` prop (SUI-7734).

API Changes:
* All components now use `KeyboardEvent`'s `key` property instead of the deprecated `keyCode` property (SUI-7352).
* `Dropdown` now exports type `DropdownPossibleOpenReason` and provides an array of `Dropdown.possibleOpenReasons` (SUI-2422).
* `Popover` now provides an array of `Popover.possibleCloseReasons` (SUI-2422).
* `Tooltip` now exports types `TooltipPossibleOpenReason` and `TooltipPossibleCloseReason`, and provides an array `Tooltip.possibleOpenReasons` and `Tooltip.possibleCloseReasons` (SUI-2422).

Bug Fixes:
* `Modal` close button now has correct `subtle` appearance.
* `Multiselect` no longer incorrectly throws a "defaultValue prop change" error in some scenarios (SUI-7777).
* `Table.HeadCell` and `Table.HeadDropdownCell` now aligns the topline of icons with multiline content (SUI-7758).
* `Table`'s cell single and multiline content now are vertically aligned (SUI-7613).
* `Markdown` now correctly renders code blocks where the language name is hyphenated (SUI-7829).

5.0.0-rc.1 - May 14, 2025
----------
New Features:
* `Card` now defaults to a borderless appearance for non-clickable cards (SUI-7651).

Bug Fixes:
* `Table`'s `rowExpansion` button now correctly displays hover styles (SUI-7772)ß.
* `Text` no longer has border hover effects incorrectly applied when `disabled` or `dimmed` (SUI-7639).
* `Switch`'s `toggle` appearance now has correct role of `switch` (SUI-7713).
* `Table.HeadCell`'s and `Table.HeadDropdownCell`'s borders now span the full cell height when content wraps to multiline (SUI-7760)
* `CollapsiblePanel` no longer flickers on open or close of panel (SUI-7620).
* `Color` now passes `className` and `elementRef` to the root element instead of an inner component, allowing proper styling with `styled-components` (SUI-6211).
* `Button`'s now have consistent styling when using `appearance="secondary"` and `isMenu` (SUI-7611).

API Changes:
* `Color`'s test hook `[data-test="color"]` is now on the root component and `[data-test="toggle-swatch"]` is on the toggle swatch. See migration guide for details (SUI-7773).
* `Dropdown`, `Search`, `FormRows`, `JSONTree`, `Number`, `RadioBar`, `TabBar`, `Table` now uses `KeyboardEvent`'s `key` property instead of deprecated `keyCode` property (SUI-7352).

Deprecations:
* `Popover`'s `"inverted"` value of the `appearance` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-6154).

5.0.0-beta.5 - May 7, 2025
----------
New Features:
* `TabBar` supports a new prop `maxTabWidth` prop (SUI-7599).
* `data-test-disabled` test hook has been added to data entry components for testing (SUI-7575).
* `Table`'s resize handler now supports hover state (SUI-7302).
* `Card.Header`'s `truncateTitle` prop now truncates title when a node with text content is passed into `title` prop (SUI-6333).
* `Typography` has reintroduced the `withReset` prop, which defaults to `true` and removes all browser-default styles while applying theme-specific defaults (SUI-7638).

Bug Fixes:
* `Message` content are now displayed using flow layout instead of flex (SUI-6271).
* `Progress` performance improved by preventing styled-components from generating excessive classes (SUI-7625).
* `Tooltip`'s toggletip focus and hover styles now have the correct shape (SUI-6155, SUI-7719).
* `Card.Header`'s `actions` now center align with the first line of the title (SUI-7657).
* `Slider` now correctly displays the bar when `minLabel` or `maxLabel` are set to null (SUI-7730).
* `Slider`'s drag handle no longer covers labels (SUI-7732).
* `RadioBar` now has improved visual contrast to better differentiate between selected and unselected options (SUI-7654).
* `Table` now correctly aligns multiline content when it wraps to a new line (SUI-7606).
* `Prose` should no longer apply margin to the last element (SUI-7227).
* `Text` now displays the `not-allowed` cursor on adornments when disabled (SUI-7532).
* `Typography`'s styles are now consistent with equivalent content components (SUI-7638).
* `Link` will now always render as an `a` tag, even when disabled (SUI-7543).
* `FormRows` correctly takes up the full width given (SUI-7716).
* `FormRows` no longer reserves extra space for remove button when rows are not removable (SUI-7717).
* `Card.Header`'s `anchor` prop is deprecated and will be removed in the next major version. See the migration guide for details (SUI-6577).

API Changes:
* `TabBar`'s `tabWidth` prop has been removed. See migration guide for details (SUI-7599).
   * For enforcing a max width of `TabBar.Tab`s use `maxTabWidth` instead.
* `Multiselect`'s `useClickawayOverlay` prop has been removed (SUI-7722).

Deprecations:
* `TabBar` and `TabLayout`'s `iconPosition` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-7736).

5.0.0-beta.4 - April 22, 2025
----------
New Features:
* `Table.HeadCell` and `Table.HeadDropdownCell` now support `headCellScreenReaderText` prop to improve screen reader usability for column reordering (SUI-7209).
* `Tootip`'s icon is now the InformationCircle in all themes (SUI-6151).
* Input components now make use of the new `inputBorderWidth` design token where applicable (SUI-7348).
* `DualListbox` now supports the `elementRef` prop (SUI-7541).
* `MessageBar` now supports the `elementRef` prop (SUI-7661).

API Changes:
* `typescript` version is now `^5.8.3` (SUI-7601).
* `Image`'s preview is now a set size, `maxHeight` prop has been removed (SUI-7137).
* `react-spring@9.2.4` has been replaced by `@react-spring/web@9.7.5` (SUI-7585).
* `SplitButton.Item` now supports `icon` prop (SUI-7556).

Bug Fixes:
* `Select` with `filter` no longer loses focus when placed above the toggle (SUI-6973).
* `Select` could throw an incorrect "defaultValue prop change" error in some scenarios that were preventable. This has been fixed (SUI-7655).
* `Popover` will now reposition when the anchor moves or is resized (SUI-7558).
* `FormRows` will now throw an error when a row is sortable and/or removable and required index is not provided (SUI-5639).
* `Text` now only renders the `aria-disabled` attribute when `disabled="dimmed"` (SUI-7574).
* Removed usage of `withComponent` improve compatibility with `styled-components@6` (SUI-7602).
* `Progress` has correct height and `box-sizing` properties (SUI-7626).
* TabBar correctly maintains focus if child Tabs position is changed (SUI-6135).

TypeScript:
* `Clickable` now exports `ClickablePropsBase`, `ClickableButtonProps`, and `ClickableLinkProps` (SUI-7563).
* `TableRequestMoveColumnHandler` type no longer provides the `columnId` property (SUI-7209).
* `TableRequestMoveRowHandler` type no longer provides the `dataId` property (SUI-7209).
* `SlidingPanel`'s `activePanelId` and `SlidingPanel.Panel`'s `panelId` are now of type string or number (SUI-7005).
* `File.Item`'s `itemId` prop and the corresponding fields in `FileRequestRemoveHandler` and `FileRequestRetryHandler` are now `string` (SUI-7603).
* `StepBar`'s `activeStepId` prop and `StepBar.Step`'s `stepId` prop are now `number` (SUI-7603).
* `Table.HeadCell` and `Table.HeadDropdownCell`'s `columnId` props and the corresponding fields in `TableRequestResizeColumnHandler`, `HeadCellSortHandler`, `HeadDropdownCellRequestOpenHandler`, and `HeadDropdownCellRequestCloseHandler` are now `string` (SUI-7603).
* `ComboBox` now exports `ComboBoxScrollBottomHandler`.
* `Layout` now exports type definitions (SUI-7635).
* `SplitButton.Item` now has exported type `ItemClickHandler` for the `onClick` prop (SUI-7556).

5.0.0-beta.3 - April 2, 2025
----------
New Features:
* `Divider` supports a new `appearance` prop that can change the divider's border color (SUI-7132).
* `File` now renders document type icon when file name has a matching extension (SUI-7363).
* `Date`'s input now displays the Calendar icon in all themes when `inputOnly={true}` and hides the icon when `inputOnly={false}` (SUI-7130).
* `SplitButton` now supports appearance `destructiveSecondary` (SUI-7136).

API Changes:
* `File`'s test hook `[data-test="file-link"]` has been removed (SUI-7122).
    * Use `[data-test="file-label"]` instead.
* `Color`'s uncontrolled mode should no longer call `onChange` on "enter" when the value did not change (SUI-7392).
* `Color`'s display string for `null` has been updated from "N/A" to "n/a" to align with the Splunk Style Guide (SUI-7392).
* `Color`'s popover input and system color picker no longer update the on-page input until the input is submitted (SUI-7392).
* `SidePanel` and `TransitionOpen` now support `elementRef` (SUI-7434).
* `Date` supports empty-string for `defaultValue` (SUI-7412).
* `FormRows` now requires reordering rows using the drag handle. Sorting/dragging the row itself is no longer supported (SUI-7036).
* `SplitButton`'s `appearance` prop now defaults to `secondary` (SUI-7136).

Bug Fixes:
* `Code` no longer applies syntax highlighting when `language` is one of `'plain', 'plaintext', 'text', 'txt'`. (SUI-7266).
* `RadioBar.Option` no longer shifts horizontally when the focused or active `Option` changes (SUI-7385).
* `Table`'s `onRequestToggle` now correctly applies `disabled` focus styles when `disabled` (SUI-7308).
* `Text` now has correct types for `placeholder` prop (SUI-7339).
* `Color`'s uncontrolled mode should no longer call `onChange` on "enter" when the value did not change.
* `Color`'s display string for `null` has been updated from "N/A" to "n/a" to align with the Splunk Style Guide.
* `Button`'s height in compact mode is now 28px, matching the design.
* `Table`'s header font size defaults to the correct size now (SUI-7383).
* `Table`'s stripe rows background color has been updated for improved contrast (SUI-7384).
* `Table` cell content now vertically aligns to the top of the cell (SUI-7269).
* `Table`'s expand and select icon cells now span the whole height of the row (SUI-7379).
* `Button` with `appearance="secondary"` and `isMenu` props now renders the correct border color.
* `Slider`'s controlled mode now correctly updates passed in value on change (SUI-7536).
* `Button`'s `propTypes` now support the `destructiveSecondary` appearance.
* `RadioBar.Option`s now grow to fill the space taken by `RadioBar` (SUI-7571).

Deprecations:
* `Multiselect`'s `"buttongroup"` value of the `selectAllAppearance` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-7293).
* `SplitButton`'s `default` value of the `appearance` prop has been deprecated and will be removed in the next major version. Use `secondary` instead (SUI-7136).

TypeScript:
* `Button` now exports `ButtonProps` (SUI-7250).

5.0.0-beta.2 - March 5, 2025
----------
API Changes:
* `Popover` now defaults `hideArrow` to `false` in all themes (SUI-7061).
* `Select` now supports `defaultPlacement` when `filter` is not set (SUI-7326).
* `Card`'s `selected` prop has been deprecated. See migration guide for details (SUI-7292).
* `Code`'s `indentChars` prop has been removed (SUI-5989).
* `Color` no longer exports method `isValidHex`. Instead use `@splunk/ui-utils/color/isValidHexColor` (SUI-2552).
* `RadioList`'s `direction` prop has been deprecated. See migration guide for details (SUI-7342).
* `Dropdown` no longer supports a `focus` method. See migration guide for details (SUI-7364).
* `ControlGroup` now defaults `labelPosition` to `top` (SUI-7331).

Bug Fixes:
* `Table`'s `actions` now correctly applies focus style in the `HeadCell`(SUI-7310).

TypeScript:
* `Select`'s type now matches component functionality by supporting the `repositionMode` prop (SUI-7326).

5.0.0-beta.1 - February 20, 2025
----------
`react-ui@5.0.0` is a major release with significant design updates.
* Many components have been updated to have similar appearance and behaviors across themes.
* As a result of a unified approach to spacing and layout, layout changes are expected. See the migration guide for specific details and guidance.

New Features:
* `Avatar` is now available to use instead of `Monogram` and supports images (SUI-3227).
* `CollapsiblePanel` now supports a new `appearance` prop with `"default"` and `"subtle"` values (SUI-5098).
* `DefinitionList` can configure the separator character used to separate key-value pairs with the new `separatorCharacter` prop (SUI-5557).
    * Enterprise themes no has a default value for the separator character (SUI-5557).
* `Link` now supports a new `appearance` prop with `"default"` and `"inline"` values (SUI-6003).
* `Markdown` uses `react-markdown` for rendering markdown content.
    * `Markdown` supports rendering tables (SUI-5624).
    * `Markdown` now can render heading levels 5 and 6.
    * Blockquotes are now rendered by default
    * All types for custom renderers have been adapted to match types of `react-markdown`.
    * Renderers do not support `propTypes` due to an incompatibility with `react-markdown` types.
* `Modal.Footer` supports a new prop `layout` with `"auto"`(default) and `"none"` values (SUI-6678).
* `Modal` no longer closes when clicking outside (SUI-5898).
* `Number` supports a new `onClick` prop (SUI-3418).
* `Select` now has a consistent visual error design across themes (SUI-6432).
* `Slider` supports new `thumbRef` prop to target the slider thumb element (SUI-7101).
* `Switch` supports a new `toggleRef` prop to target the underlying toggle element (SUI-7101).
* `TabBar.Tab` now generates a `tabId` automatically if `tabId` prop is not passed (SUI-7033).
* `TabLayout.Panel`s support a new `inset` prop (default `true`) to control padding in the panel (SUI-5705).
* `Text` now always displays the clear button when the `canClear` prop is present and a value is entered (SUI-6986).
* `Typography`'s `lineHeight` supports a new scale: `"single"`, `"tight"`, `"snug"`, `
* `WaitSpinner` now supports prop `size="large"` for Enterprise themes (SUI-6080)."comfortable"`, `"relaxed"`, `"spacious"`, `"normal"`.
* New `Layout` component can be used to arrange components with standard spacing between them (SUI-6678).
* New `Prose` component can be used to style content components for long-form text content (SUI-5504).

API Changes:
* `react` and `react-dom` peer dependencies are now `"^16.8.0 || ^17.0.0 || ^18.0.0"`.
* Adopt `@splunk/themes@1.0.0`
* `Paragraph`, `Heading`, and `List` no longer have margin outside their border box (SUI-5683).
* Components that support the `inline` prop no longer add margin-left when a sibling to another `inline` element. See the migration guide for details. (SUI-6678).
* `Button`, `Clickable`, `CollapsiblePanel`, and `Menu.Item` default behavior for the `disabled` prop is now `"dimmed"` (SUI-7200).
    * The `disabled` prop supports a new `"disabled"` value.
    * A new `data-test-disabled` test hook has been added for testing.

* `Accordion`'s `inset` prop now defaults to `true`. Unified `Accordion`'s `inset` padding values to match `CollapsiblePanel` (SUI-2559).

* `Button`'s `appearance` prop no longer supports the `"flat"`, `"pill"`, or `"toggle"` values (SUI-6561).
* `Button`'s `selected` prop has been removed (SUI-6058).
* `Button` no longer supports the `error` prop.
* `Button`'s `label` prop no longer sets HTML `label` attribute. See migration guide for details (SUI-6054).

* `Card` and `Card.Footer`'s `showBorder` prop has been removed (SUI-6577).

* `Clickable`'s `NavigationProvider` `prefix` prop has been removed (SUI-7103).

* `CollapsiblePanel`'s `inset` prop now defaults to `true` (SUI-5760).
* `CollapsiblePanel`'s `onRequestClose` and `onRequestOpen` props have been removed. Use `onChange` instead (SUI-6226).
* `CollapsiblePanel`'s `titleWithActions` prop has been removed. Use `actions` prop instead (SUI-6355).

* `Color`'s `hideInput` prop now defaults to `false` in both Enterprise and Prisma themes, making the input field always visible by default (SUI-6459).
* `Color`'s `defaultPalette` is now equal to the data viz static colors (SUI-6405).

* `ComboBox`, `ControlGroup`, and `StaticContent`'s `size` prop has been removed (SUI-6400).

* `Concertina` has been removed (SUI-5741).

* `ControlGroup`'s label text is now left aligned in Enterprise theme when `labelPosition="left"` (SUI-6408).

* `DefinitionList`'s `termWidth` prop now requires fully qualified style value as a string, eg. `"120px"` (SUI-5557).
* `DefinitionList.Term` and `DefinitionList.Description` now require the `children` prop.

* `Dropdown`'s `toggle` prop no longer accepts React class components or functional components without `React.forwardRef` (SUI-3532).

* `Heading`'s `level='s'` and `level='ss'` have been removed. See migration guide for details (SUI-5583).
* `Heading` now requires the `children` prop (SUI-5665).

* `JSONTree`'s `expandChildren="withShiftModifier"` value has been removed. Use the `expandChildrenOnShiftKey` prop instead (SUI-5808).
* `JSONTree`'s `expandChildrenOnShiftKey` prop now defaults to `true` (SUI-5841).
* `JSONTree`'s `expandChildren` prop has been renamed to `defaultExpanded` and no longer affects node expansion behavior after the initial render (SUI-5813).

* `Link` now renders an `a` element instead of a `button` element when disabled (SUI-6007).

* `List`'s `type` prop has been removed. Use CSS to style the `list-style-type` property (SUI-5622).

* `Menu`'s `retainFocus` prop has been removed. Use `focusMode` prop instead (SUI-6164).
* `Menu`'s `focusMode` prop now defaults to `roving` (SUI-6164).
* `Menu.Item` and `Search.Option`'s `icon` prop has been removed. Use `startAdornment` and/or `endAdornment` instead (SUI-6762).

* `Message` no longer supports `appearance="banner"` (SUI-6123).
* `Message.Link` has been removed. Use `Link` instead (SUI-6124).
* `Message` now has a maximum width (SUI-6122).

* `Modal`'s `returnFocus` prop is now required (SUI-5996).
* `Modal.Header` no longer supports the `onRequestClose` prop (SUI-5933).
    * The close button in `Modal.Header` now calls the `onRequestClose` handler from `Modal`.
    * If closed with the close button in `Modal.Header`, the `reason` parameter of `Modal`'s `onRequestClose` prop will be set to `"clickCloseButton"`.
* `Modal` with on `onRequestClose` set will display the close button in the `Modal.Header` by default.
    * This can be hidden by passing the `hideCloseButton` prop to `Modal.Header` (SUI-5933).
* `Modal.Footer` has updated default styling. This can be reverted by setting `layout="none"` (SUI-6678).

* `Monogram`'s `xlarge` option for `size` prop has been removed (SUI-3222).

* `Number`'s `placeholder` and `useSyntheticPlaceholder` props have been removed (SUI-7070).

* `Popover`'s `anchor` prop now requires a ref to a HTML element and no longer accepts refs to React class component instances (SUI-3532).
* `Popover` is now center-aligned in both Enterprise and Prisma themes (SUI-7038).

* `Progress` has been redesigned:
    * Native HTML `<progress>` element is used
    * New visual design to allow all parts of the component to hit required contrast ratios.
* `Progress` `type="warning"` has been removed (SUI-6491).

* `RadioBar`'s `appearance` prop has been removed (SUI-6386).
* `RadioBar`'s `icon` prop has been removed (SUI-7104).

* `Search`'s icon placement is now at the start of the input in all themes (SUI-6242).

* `Select`'s `appearance` prop no longer supports the `"primary"`, `"pill"`, `"flat"`, or `"toggle"` values. (SUI-6440, SUI-6866).
    * The default value of `appearance` is now `"default"`.

* `Slider`'s test hook `[data-test="handle"]` has been renamed to `[data-test="thumb"]` (SUI-7101).

* `Switch`'s test hook `[data-test="button"]` has been renamed to `[data-test="toggle"]` (SUI-7101).

* `Table.HeadDropdownCell`'s `defaultPlacement` prop has been removed (SUI-6742).
* `Table.HeadDropdownCell` supports a new `buttonRef` prop to target the underlying button (SUI-6843).

* `TabBar`'s  and `TabLayout`'s `appearance` prop has been removed (SUI-6835).
* `TabBar`'s  and `TabLayout`'s `iconSize` prop has been removed (SUI-6960).

* `TabLayout`'s unused `count` prop was removed (SUI-7047).

* `Text`'s `appearance` prop has been removed. Use `Search` component instead of `appearance="search"` (SUI-5978).
* `Text`'s `placeholder` and `useSyntheticPlaceholder` props have been removed (SUI-5979, SUI-5977).
* `Text`'s `multiline`, `rowsMax`, `rowsMin` props have been removed (SUI-5975).
* `Text`'s `onInputClick` prop has been renamed to `onClick` (SUI-5952).
* `Text` and `TextArea` now only apply the `className` prop to the root element (SUI-6214).

* `TextArea`'s `canClear` prop has been removed (SUI-6061).
* `TextArea`'s `placeholder` prop has been removed (SUI-6061).

* `Tooltip` prop `defaultPlacement` no longer supports value `"theme"`.
    * `defaultPlacement` now defaults to `"above"` for all themes.
* `Tooltip` `appearance` is now `"normal"` for all themes.

* `Typography`'s `weight` prop no longer supports numeric values. Use the equivalent keyword value instead (SUI-5679).
* `Typography`'s `withReset` prop has been removed (SUI-5686).
* `Typography` has been updated to align with the themes mixin:
    * `variant` no longer supports `"title7"` and `"footnote"`.
    * `size` no longer supports `56`, `36`, `32`, and `10`.
    * `lineHeight` no longer supports pixel values.

* `WaitSpinner` can now be styled with `styled-components` (SUI-6213).
* `WaitSpinner`'s `elementRef` is now set to the component's root element (SUI-6213).

Bug Fixes:
* `Modal.Header`'s `icon` prop no longer requires `width="100%" height="100%"` to be set on the icon to render at the correct size (SUI-5931).
* `Link`s are now underlined on focus and hover to improve accessibility (SUI-2835).
* `ControlGroup`'s error text now has a new visual style and renders an icon to improve accessibility (SUI-6395).
* `Color`'s selected swatch checkmark color is now white or black based on the swatch value to have improved contrast (SUI-6404).
* `Popover`'s arrow border color in Enterprise themes now matches `Popover`'s content background color (SUI-6671).
* `Number`'s step buttons now show in Enterprise themes when disabled (SUI-7073).
* `Card.Header` no longer erroneously adds extra padding-bottom when it is the last child within its parent (SUI-6818).

Docs:
* `WaitSpinner`'s `children` prop was improperly documented in PropTypes as being allowed. This has been fixed (SUI-6081).

TypeScript:
* `Color`'s `ExpandClickHandler` type has been removed (SUI-6405).
* `ComboBox`, `Date`, `Multiselect`, `Number`, `Search`, `Select`, and `Text` no longer use the TypeScript `HTMLTextAreaElement` type in event handlers and refs (SUI-6206).
* `Date`'s `onClick` prop now uses TypeScript `HTMLInputElement` type (SUI-5952).
* `TextArea`'s `inputRef` prop is now `HTMLTextAreaElement`.
* `TextArea`'s `TextAreaChangeHandler` `event` type is now `React.ChangeEvent<HTMLTextAreaElement>`.

Deprecations:
* `Accordion` has been deprecated and will be removed in a future major version. Use `CollapsiblePanel`'s `SingleOpenPanelGroup` API instead (SUI-5827).
* `Monogram` has been deprecated and will be removed in a future major version. Use `Avatar` instead (SUI-5608).
* `Select`'s `"link"` value of the `appearance` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-6724).


4.45.0 - May 6, 2025
----------
Bug Fixes:
* `Table` now displays `cursor: default` when a row is not clickable and is an empty action cell (SUI-7232).
* `Table` now maintains consistent IDs for expansion rows through renders (SUI-7698).
* `Layer` will now render at the correct `z-index` when `separateStackingContexts` is set in `LayerStackGlobalProvider` (SUI-7241).
* `Concertina`, `File`, `Layer`, `Slider`, `Resize`, and `TextArea` will no longer cause issues with server-side rendering (SUI-7737)

4.44.1 - April 10, 2025
----------
Bug Fixes:
* `Combobox` and `Multiselect` no longer call `onOpen` after selecting a value (SUI-7624).

4.44.0 - April 1, 2025
----------
New Features:
* `Number`'s `onChange` handler now includes a `reason` property in callback data (SUI-7401).
* `Date` does not render 'Invalid value' for empty strings when controlled (SUI-5993).
* `Date` does not revert value for empty strings when uncontrolled (SUI-5993).

Bug Fixes:
* `StaticContent` supports new prop `labelledBy` (SUI-5326).
* `Clickable` now displays the `not-allowed` cursor when disabled (SUI-7297).
* `Table` now renders dynamically added expansionRows (SUI-7403).
* `ButtonGroup`'s `role` has changed from `menubar` to `group`. Child `Button`'s `role`s have changed from `menuitem` to `button`. See the migration guide for details (SUI-6551).
* `Table`'s resize handler no longer triggers sorting or opening dropdown when `enter` key is pressed (SUI-7320).
* `Slider`'s disabled state now prevents the appearance of thumb focus when active and displays `not-allowed` cursor on the entire input (SUI-7498).
* `Table`'s stripe rows now extend all the way across the table for rows without actions (SUI-7232).

4.43.0 - March 4, 2025
----------
New Features:
* `Popover` supports a new `hideArrow` prop that controls whether or not to render the arrow pointing to the anchor (SUI-7061).
    * Defaults to `false` in Enterprise and `true` in Prisma themes, maintaining existing behavior.
* A new `PopoverProvider` component has been added that supports a `hideArrow` prop to control whether or not any components using `Popover` render the arrow pointing to the anchor (SUI-5262).
    * This controls `Color`, `ComboBox`, `Dropdown`, `Select`, `Multiselect`, `Search`, `SplitButton`, and `Tooltip`.
* `Paginator` supports a new `generatePageProps` prop for customizing pages and Prev/Next buttons (SUI-6991).
* `Code` now supports `language` `plaintext` (including additional aliases `plain`, `text`, and `txt`) (SUI-7266).

Bug Fixes:
* `Select`'s `filter` no longer has `aria-owns` attribute when blurred (SUI-7208).
* `Number` now correctly prevents multiple decimals (SUI-7234).
* `Menu` and `TabBar` now correctly ignore keyboard navigation when command key is pressed (SUI-7115).
* `Popover`'s arrow is no longer misaligned when using `pointTo` or `align="edge"` (SUI-7191).
* `CollapsiblePanel` now correctly applies height when content includes image (SUI-7084).
* `Code` no longer applies `tabIndex=0` to static (non-scrollable) content (SUI-7325).
* `JSONTree` now expands or collapses non-root nodes when the `enter` key is pressed (SUI-7076).

Typescript:
* `MultiselectChangeHandler` type now includes optional `reason` property in callback data (SUI-7222).
* `Message` now correctly handles whitespace around `Link` (SUI-6271).

Docs:
* Added missing documentation for `ComboBox`'s `inputId` prop (SUI-7090).
Bug Fixes:
* `Select`'s `filter` no longer has `aria-owns` attribute when blurred (SUI-7208).

4.42.0 - February 5, 2025
----------
New Features:
* `SelectBase`'s `aria-label` attribute is omitted when the `labelledBy` prop is provided, since `aria-labelledby` takes precedence over `aria-label` in screen reader announcements (A11Y-3350).
* `Tooltip` has a new `renderAnchor` prop for rendering a `Tooltip` without a wrapper element (A11Y-3260).

Bug Fixes:
* `Text` and `TextArea`'s border has been updated to improve contrast in Enterprise dark themes (SUI-6984).
* `Table`'s dropdown cells in header are now accessible with keyboard (A11Y-3007).
* `Table`'s expandable row controls are now accessible with VoiceOver (SUI-6188).
* `Multiselect` with `compact` no longer shows an extra divider when used with `Multiselect.Heading` (SUI-7031).
* `Menu.Item` will now display a correct cursor ('not-allowed') when hovering over checkbox in disabled option in `Multiselect` with `compact` (A11Y-3397).
* `Popover` is now correctly positioned when the anchor is inside a container with `transform: scale()` (SUI-3423).
* `Layer` will now render its child components when the browser is in fullscreen mode (SUI-2741).
    * This also fixes the issue for components that use `Layer`: eg.`Dropdown`, `Popover`, etc.
* `Table`'s cells content are now vertically centered when there's an action column in Enterprise themes (SUI-7093).
* `Dropdown`, `Select`, and `SelectBase` with filter will now set an additional id in `aria-labelledby` on popover, providing an additional screen reader announcement with the text `Type to filter` to indicate the presence of a filtering option (A11Y-3336).

Typescript:
* `Dropdown` does not show a TS error when passed native HTML attributes as props (A11Y-3336).
* `Link` will no longer fail to build in TypeScript projects due to an invalid `LinkStyles` export (SUI-7195).

4.41.0 - January 7, 2025
----------
New Features:
* `Table` now supports `actions`, `actionsColumnWidth`, `actionPrimary`, and `actionsSecondary` in Enterprise themes (SUI-6885).

Bug Fixes:
* `Multiselect.Compact` no longer discards passed keys and generates default keys for children in lists (SUI-6977).
* `Menu.Heading` no longer adds `aria-hidden="false"` to the DOM incorrectly in certain scenarios (SUI-6958).
* `RadioBar` will no longer incorrectly have extra spacing when switching from Prisma to Enterprise themes (SUI-6906).
* `Select` and `Multiselect` now correctly display headings and no options message when filtering (SUI-6949).
* `RadioBar.Option` has the correct background color when focused in Prisma themes (SUI-6982).
* `CollapsiblePanel` and `TransitionOpen` will no longer get stuck at zero height when `renderChildrenWhenCollapsed` is true (SUI-6989).
* `MessageBar` now applies the correct styles to `Link`s without the `to` prop (SUI-7002).
* `RadioBar` sets `aria-disabled="true"` on the group when all child options are disabled. (SUI-7021).

Typescript:
* `Slider`'s error prop has been corrected to be optional (SUI-6504).

4.40.0 - December 3, 2024
----------
New Features:
* `Table` now supports clickable cells in Prisma themes (SUI-6571).
* `Chip` now supports all `appearance` values in all themes (SUI-6856).
* `Multiselect` now supports the `selectedAppearance` prop in Prisma themes (SUI-6856).
* `WaitSpinner` now supports `size="large"` in Enterprise themes (SUI-6902).
* `TabBar` and `TabLayout` now support a new `iconPosition` prop (SUI-6901).

Bug Fixes:
* `Number` now has the role of `spinbutton` and adds the associated aria attributes (A11Y-2976).
* `useKeyPress` types are now being exported (SUI-6862).
* `Popover`'s fading out animation now does not allow click through (SUI-6618, SUI-6456).
* `Table.HeadCell` with sortable headers is now correctly announced by screen readers (SUI-6672).
* `Message.Title` no longer is inline with other content (SUI-6250).
* `TabBar.Tab` and `TabLayout.Panel` are no longer incorrectly sized if the `label` attribute is not a string (SUI-6877).
* `SplitButton` types are now being exported (SUI-6306).
* `ResultsMenu`'s no option item has now appropriate contrast (SUI-6543).

Deprecations:
* `Select`'s `"primary"` value of the `appearance` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-6866).
* `Card` and `Card.Footer`'s `showBorder` prop is deprecated and will be removed in the next major version (SUI-6577).
* `TabBar` and `TabLayout`'s `iconSize` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-6901).

4.39.0 - November 8, 2024
----------
New Features:
* `File` supports `onRequestRetry` in Enterprise themes (SUI-6579).
* `ControlGroup`'s `controlsLayout="fillJoin"` value is now supported in Prisma (SUI-6676).
* `StepBar` now supports the `error` prop on `Step`s in Enterprise themes (SUI-6578).
* `Table` supports `stripeRows` in Prisma themes (SUI-6574).
* `Popover` supports `appearance="inverted"` in Prisma themes (SUI-6581).
* `Menu.Item`'s `selected` prop now supports the value `'some'`, which indicates a partially selected state (SUI-6746).
* `Menu.Item` and `Search.Option` now support `startAdornment` and `endAdornment` props (SUI-6429).

Bug Fixes:
* `ControlGroup` properly announces a11y labels with `fillJoin` value for `controlsLayout` prop (SUI-6424).
* `Color`'s text input now properly becomes disabled when `disabled` prop is passed (SUI-6680).
* `Table.Row` no longer triggers its `onClick` callback or sets a pointer cursor on the actions column created by the `actionPrimary` or `actionSecondary` props (SUI-6427).
* `Switch`'s error styles for `border-color` in hover states have been corrected in Prisma and corrected for selected and hover states in Enterprise (SUI-6651).
* `Switch`'s icon color has been corrected and will default to `accentColorNegative` in Enterprise theme (SUI-6651).
* `Menu.Item` with right description has been vertically aligned for Prisma themes (SUI-6535).
* `ComboBox` now allows to set `aria-label` value and has default value removed (SUI-6533).
* `RadioBar` and `RadioList` now set `aria-invalid` when there's an error (SUI-6523).
* `List` and `Markdown` will no longer incorrectly number ordered lists in Firefox (SUI-6855).

Deprecations:
* `Button`'s `selected` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-6704).
* `Table.HeadDropdownCell`'s `defaultPlacement` prop has been deprecated and will be removed in the next major version (SUI-6489).
* `TabBar` and `TabLayout`'s `appearance` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-6834).
* `Menu.Item` and `Search.Option`'s `icon` prop has been deprecated and will be removed in the next major version. Use `startAdornment` and/or `endAdornment` instead (SUI-6429).

4.38.0 - October 1, 2024
----------
New Features:
* `Slider` now supports the `error` prop in Enterprise themes (SUI-6580).
* `Search.Option` now supports the `matchRanges` prop (SUI-6383).
* `Text` now supports a new `"dimmed"` value for the `disabled` prop (SUI-6648).
* `Button` and `Menu.Item` support type `string` for `openInNewContext` to customize the default message (SUI-6662).
* `Date` now supports the `inputOnly` prop in Enterprise themes (SUI-6579).

Bug Fixes:
* `Color`'s palette now renders with the correct role and has an accessible name (SUI-6635).
* `Select` with `prefixLabel` or `suffixLabel` now has correct `aria-label` when option is selected (SUI-6642).
* `Select`'s `role` has been changed from `"button"` to `"combobox"` (SUI-6441).
    * Screen reader now announces the `option` selection status and number within the `listbox`.
* `Color`'s interactive elements are additionally labelled by ControlGroup (SUI-6660).
* `Button` and `Menu.Item` now correctly informs users when a link will open in a new window in Prisma themes (SUI-6662).
* `Button` and `Menu.Item` have updated screen reader text better describing the `openInNewContext` behavior to users (SUI-6662).

Docs:
* New `List`, `Paginator`, `Table`, and `TextArea` component overviews.

4.37.0 - September 9, 2024
----------
New Features:
* `Progress` supports `success` and `error` values for the `type` prop in Enterprise themes (SUI-6492).

Bug Fixes:
* Updated `Progress` animation and style to improve contrast in Enterprise themes (SUI-6492).
* `RadioBar`'s active item now has appropriate contrast in the Prisma light theme (SUI-6609).
* `Switch` now shows the correct cursor type when `appearance="toggle"` is `disabled` (SUI-6612).
* `TextArea` with `startAdornment` or `endAdornment` will no longer prematurely wrap text (SUI-6613).

4.36.0 - September 3, 2024
----------
New Features:
* `Resize` now accepts `separator` as a value for the `appearance` prop which makes the resize button span the entire border (SUI-6600)

Bug Fixes:
* `Slider` has increased color contrast in Enterprise themes (SUI-6259).
* `JSONTree` will no longer crash when the `json` prop changes (SUI-6182).
* `Multiselect`'s options are no longer clickable when they are fading out (SUI-5901).
* `Multiselect`'s options are shown again when clicking after being previously dismissed with ESC key (SUI-6128).
* `TabBar` now correctly handles focus when `Tab` children are reordered (SUI-6599).

Deprecations:
* `ComboBox`, `ControlGroup`, and `StaticContent`'s  `size` prop has been deprecated and will be removed in the next major version. It has no effect in `@splunk/react-ui@4` and was incorrectly listed in the API documentation. (SUI-6400).

4.35.0 - August 26, 2024
----------
New Features:
* `Color`'s `hideInput` prop is now supported in Enterprise themes. Defaults to `true` in Enterprise and `false` in Prisma themes, maintaining existing behavior (SUI-6458).
* `Menu.Item` now supports a new `"dimmed"` value for the `disabled` prop (SUI-5671).
* `ControlGroup` uses `aria-errormessage` to help associate the input with its error message (SUI-6395).
* Refactored uses of styled-components `withComponent` functionality to increase compatibility with styled-components v6 where it will no longer be available (SUI-6285).
* `Search.Option` now supports the `onClick`, `to`, and `openInNewContext` props (SUI-5249).

Bug Fixes:
* `Button` with `inline={false}` now aligns correctly with text when set to `display: inline-block` (SUI-6472).
* `Text`'s border now shows focus when clicked and has a cursor text when hovering over the border now (SUI-5199).
* `Text`'s non-clickable adornments now shows focus on the input when clicked (SUI-5199).
* Reverted change to `CollapsiblePanel` focus shadow, now uses inset shadow:
    * Note `@splunk/themes@0.21.0` should be used to ensure contrast requirements are met.
* `Message`'s remove button styling for focus and hover states has been corrected (SUI-6520).

Deprecations:
* `Progress`'s `type="warning"` value has been deprecated and will be removed in the next major version.
* `Menu` now supports `focusMode` prop, which specifies how the menu manages focus (SUI-6164).
* `Menu`'s `retainFocus` prop has been deprecated and will be removed in the next major version. See the migration guide for details (SUI-6164).

Docs:
* `Combobox.Option`, `Multiselect.Option`, `Search.Option` and `Select.Option` no longer incorrectly list `descriptionPosition="right"` as unsupported in Prisma themes (SUI-6568).

4.34.0 - August 7, 2024
----------
New Features:
* `RadioBar` supports new prop `role` for either `radiogroup` (default) or `menubar` (SUI-6335).
* `CollapsiblePanel` has a new `actions` prop for rendering the toggle button and interactive elements separate from `title`, reserving the `title` prop for text only (SUI-5999).
    * If using the new `actions` prop, the toggle button supports `aria-labelledby` with the title and the panel body supports `role='region'`.
* `Select` now supports `appearance="subtle"` with the same visual appearance as the Enterprise `"pill"` and Prisma `"secondary"` appearances (SUI-6440).
* `Card` has a new `actions` prop for rendering card actions. This should be used to add unambiguous labels to the secondary actions, see the migration guide for details (SUI-5881).
* `Card` has a new `tag` prop for overriding the default HTML tag (SUI-5881).

Bug Fixes:
* `CollapsiblePanel` now correctly announces its expanded state to a11y tools in Firefox (SUI-5999).
* `RadioBar` no longer warns about the deprecated `appearance` prop when the default value is used.
* `Button` now shows focus styling when hovered (SUI-6357).
* `Button`s with an `appearance` of `primary` or `destructive` no longer have incorrect background colors on focus when `disabled="dimmed"` (SUI-6357).
* `JSONTree's` active border has been removed to avoid a layout shift (SUI-6324).
* `CollapsiblePanel`'s focus shadow has been updated to improve contrast (SUI-6340).
* `Search`'s `role` has been changed from `"textbox"` to `"searchbox"`.
* `Search`'s default labels have been removed to avoid redundant screen reader output (SUI-6332).
* `CollapsiblePanel`'s Enterprise dark theme toggle button is now visible when `disabled` (SUI-6425).
* `Popover` no longer moves focus to the container when no focusable children exist to ensure the focus indicator remains visible (SUI-6446).
* `Card` uses the `article` tag instead of `div` by default (SUI-5881).
* `Menu` no longer takes focus when all `Menu.Item` children are disabled (SUI-6268).
* `Color`'s textbox swatch in the popover palette is now focusable in Enterprise themes (SUI-6401).
* `Menu`s last `Item` no longer has an incorrect border radius on hover when a `footerMessage` is set (SUI-6450).

Deprecations:
* `CollapsiblePanel`'s `titleWithActions` prop has been deprecated and will be removed in the next major version. Use the new `actions` prop instead to render the toggle button and interactive elements separate from `title` (SUI-5999).
* `Select`'s `"flat"`, `"pill"`, and `"toggle"` values of the `appearance` prop have been deprecated and will be removed in the next major version. See the migration guide for details (SUI-6440).

4.33.0 - July 8, 2024
----------
New Features:
* `Clickable` now supports the `"dimmed"` value for the `disabled` prop (SUI-5819).
    * If set to `"dimmed"`, the component does not respond to mouse events and `aria-disabled` is set to `true`.
* `Button` now supports `appearance="subtle"` with a visual appearance similar to the Enterprise `"pill"` and Prisma `"secondary"` appearances (SUI-6051).
* `Button` now sets the `aria-pressed` attribute appropriately when the `selected` prop is provided (SUI-2791).
* `Select` has a new `toggleContent` prop that specifies whether the children (`"optionChildren"`) or label (`"optionLabel"`) of the matched `Option` are rendered in the toggle button (SUI-6316).
* `Menu.Item`, `Combobox.Option`, `Multiselect.Option`, `Search.Option` and `Select.Option` now support `descriptionPosition="right"` for Prisma themes (SUI-5664).

Bug Fixes:
* `Modal.Header` uses semantic HTML elements for the `title` and `subtitle` props to improve accessibility.
* `TabBar.Tab` has a correctly sized active indicator when vertical and the `to` prop is passed (SUI-6205).
* `Button`'s text is now centered correctly when combining the `icon` and `to` props (SUI-6331).
* `Button`'s external icon now has the same size as an icon rendered by the `icon` prop (SUI-6255).
* `Select` now constructs `aria-label` out of the `Option`-s `label`s rather than `children` (SUI-6316).
* `Search` now allows provided `aria-label` value to override the default `aria-label` value (SUI-6332).

Deprecations:
* `Button`'s `"flat"`, `"pill"`, and `"toggle"` values of the `appearance` prop have been deprecated and will be removed in the next major version (SUI-6501).

Docs:
* Fixed an issue where `SidePanel`'s Test Hooks content was not shown (SUI-6322).

4.32.0 - June 4, 2024
----------
New Features:
* `Clickable`'s `NavigationProvider` now accepts a new `onLinkClick` prop to handle click events globally (SUI-5291).

Typescript:
* `Card`'s `selected` prop now requires `onClick` to also be provided (SUI-6200).

4.31.0 - May 16, 2024
----------
New Features:
* `Divider` has a new `decorative` prop for disabling the default semantics of `role="separator"`.

Bug Fixes:
* `SidePanel` incorrectly rendered the overlay mask when `useLayerForClickAway={false}`. This has been fixed (SUI-6260).

4.30.0 - May 6, 2024
----------
New Features:
* `Clickable`'s `NavigationProvider` now accepts a `transformUrl` prop for modifying the URL (SUI-5291).

Bug Fixes:
* `Table.Row` keyboard reordering now works correctly and provides accessible info (SUI-2527).
* `Search`'s `aria-*` attributes have been corrected (SUI-6110):
    * `aria-expanded` is no longer added when there are no `Option`s
    * `aria-activedescendant` is no longer added when `Option`s are hidden or when no `Option` is active
    * `aria-controls` now refers to the correct element
* `Combobox` no longer adds the `aria-activedescendant` attribute when no `Option` is active (SUI-6110).
* `Multiselect` with `compact` now applies `aria-multiselectable` and `aria-controls` to the correct element (SUI-6105).
* `Multiselect` with `compact` no longer adds `aria-activedescendant` when `Option`s are hidden (SUI-6105).
* `Paginator`'s font weights and text colors have been updated to improve the perceivability of the current page (SUI-5850).
* `Text`'s `appearance` prop has been deprecated and will be removed in the next major version (SUI-5978).
* `Message`'s `type` is now announced to screen readers (SUI-5949).
* `Card` now has a visible focus indicator when selectable or clickable (SUI-2829).
* `Date` can now be styled with `styled-components` (SUI-6168).
* `Code`'s syntax highlighting colors in the Enterprise dark theme now have improved contrast (WCAG SC 1.4.3) (SUI-3573).
* `StepBar`'s text color in the Enterprise light theme now has improved contrast (WCAG SC 1.4.3) (SUI-6198).
* `Menu.Item`'s selected icon now aligns with the top of the label (SUI-6115).
* Fixed a bug in `SingleOpenPanelGroup` where a `CollapsiblePanel` would fire the incorrect action callback (SUI-6239).

Deprecations:
* `NavigationProvider`'s `prefix` prop has been deprecated and will be removed in the next major version. Use the `transformUrl` prop instead. (SUI-6239)


4.29.0 - April 2, 2024
----------
Bug Fixes:
* Removable `Chip` screen reader announcement has been improved (SUI-5948).
* `ComboBox` no longer incorrectly sets the `aria-activedescendant` attribute when closed (SUI-6108).
* `Multiselect` no longer announces incorrect available actions to screen readers (SUI-6009).
* `Search` can now be styled with `styled-components`(SUI-5720).

Docs:
* `MessageBar` examples updated to demonstrate method for labelling the component to meet WAI-ARIA specification (SUI-5941).

Deprecations:
* `WaitSpinner`'s `children` prop has been deprecated and will be removed in the next major version (SUI-6081).

4.28.2 - March 22, 2024
----------
Bug Fixes:
* `Table.Row` no longer ignores provided `style` properties (SUI-6156).

Typescript:
* `WaitSpinner`'s `screenReaderText` type includes `null` now (SUI-6081).

4.28.1 - March 21, 2024
----------
Bug Fixes:
* Fixed `CollapsiblePanel` not calling its `onRequestOpen` and `onRequestClose` callbacks (SUI-6146).
* Fixed documentation issues and discrepancies between the `onChange` callbacks of `CollapsiblePanel` and `SingleOpenPanelGroup` (SUI-6145).
    * `CollapsiblePanel` and `SingleOpenPanelGroup` will both always provide the `panelId` to their `onChange` callback.
    * `CollapsiblePanel` and `SingleOpenPanelGroup` will both provide an `action="open"|"closed"` value to the `onChange` callback.

4.28.0 - March 20, 2024
----------
New Features:
* `JSONTree` now supports tree view interactions improving keyboard accessibility (SUI-5749).
    * Up and down arrow keys navigate to previous and next visible tree nodes.
    * Right arrow key opens a closed node or moves focus to first child node.
    * Left arrow key closes an open node or moves focus to parent node.
    * Home and End keys nagivate to first and last nodes in the tree respectively.
* `Paginator` now has two additional appearances (SUI-5848).
    * `Paginator.PageControl` provides a page dropdown and previous/next buttons.
    * `Paginator.Compact` provides a customizable label and previous/next buttons.

Bug Fixes:
* `TabBar` keyboard navigation now works correctly when the `elementRef` prop is passed to `TabBar.Tab` (SUI-5409).
* `TextArea` renders the correct icon in Enterprise themes when the `canClear` prop is present (SUI-6104).
* `Markdown`'s renderers can now be styled with `styled-components` (SUI-6071).
* `Multiselect` now announces selections to screen readers (SUI-2013).
* `Table.HeadDropdownCell` does not shift horizontally when dropdown content is clicked (SUI-5457).
* `Button`'s focus style for `appearance=toggle` has been replaced with `@splunk/theme`'s `focusShadow` in Prisma themes to have a visible focus indicator (WCAG SC 2.4.7) (SUI-3081).
    * This change also affects `Select` component.
* `Select` error state is now visible when inputs are focused (SUI-5327).

Typescript:
* `Paginator's `elementRef` is now a `React.Ref<HTMLElement>` due to the underlying HTML element changing from a `div` to a `nav` (SUi-6134).

4.27.0 - March 5, 2024
----------
New Features:
* `CollapsiblePanel` now supports the functionalities of `Accordion` (SUI-5719):
    * The new `SingleOpenPanelGroup` component can be used wrap multiple `CollapsiblePanel` to replicate the   expand/collapse behavior of `Accordion`.
    * `CollapsiblePanel` supports a new `inset` prop with similar functionality as the same prop in `Accordion`.
    * A new `onChange` prop consolidates the callback behavior of the `onRequestClose` and `onRequestOpen` props.
    * The separate `onRequestClose` and `onRequestOpen` props have been deprecated and will be removed in the next major version.
* `ControlGroup` now supports `data-test-required` test hook. (SUI-6067).
* `Modal`'s `returnFocus` prop can now accept either a ref or a callback function. Use a callback function for manually setting focus when a ref cannot be used (SUI-6094).

Bug Fixes:
* `Text`'s focus style has been replaced with `@splunk/theme`'s `focusShadow` in Prisma themes to have a visible focus indicator (WCAG SC 2.4.7) (SUI-5321).
  * Error state is now visible when inputs are focused.
  * This change also affects the following components: `Combobox`, `Date`, `TextArea`, `Number`, `Select`'s and `Mutltiselect`'s filters, and `Search`.
* `Table`'s column resize handle is now correctly announced by screen readers (SUI-5967).
    * The element has been changed from a `button` to an `hr` to have the correct role of `separator`.
* `Table`'s selectable row checkboxes are now accessible with VoiceOver keys (SUI-5958).
* `Table`'s selectable row checkboxes will no longer receive focus when the row is `disabled` (SUI-5824).
* `CollapsiblePanel`'s toggle has consistent spacing and improved focus styling when `titleWithActions` is enabled(SUI-5433).

Typescript:
* The `event` type for `TableRequestResizeColumnHandler` in the `Table` has been changed from a `button` event type to an `hr` event type: `event: React.MouseEvent<HTMLHRElement> | React.KeyboardEvent<HTMLHRElement> | MouseEvent`.

4.26.0 - Feb 21, 2024
----------
New Features:
* `Modal` automatically returns focus to the invoking element after close when a ref is provided to the new prop `returnFocus` (SUI-2834).
* `Breadcrumbs` and `Breadcrumbs.Item` now support `onClick` prop (SUI-5911).

Bug Fixes:
* `TextArea`'s test selector is now `data-test="text-area"` rather than `data-test="text"` (SUI-5964).
* The icon in `Modal.Header` is now aligned with the top of the title (SUI-5930).
* `TextArea` renders at the correct size when `minRows={1}` (SUI-6010).
* `TextArea` has consistent height when rendering rows regardless if value is present.
* Fixed spurious deprecation warnings for `canClear` and `placeholder` props in `TextArea`.
* Fixed regression in `TextArea` where placeholder text could be cut off.
* Improved the row drag and drop experience and performance by adopting `@dnd-kit` in `Table` component (SUI-5134).

API Changes:
* Corrected the type of `Modal`'s `initialFocus` prop to include `React.Component & { focus: () => void }` instead of  `React.Component & { focus: () => {} }`.

4.25.0 - Feb 6, 2024
----------
New Features:
* `Modal` supports `subtitle` and `icon` props in Enterprise themes (SUI-5924).
* `Button` now supports a new `"dimmed"` value for the `disabled` prop (SUI-5819).

Bug Fixes:
* `Modal`'s `subtitle` is used as the accessible description for the dialog (SUI-5264).
* `Color`'s `required` attribute is correctly applied when inside a `ControlGroup` in Prisma themes (SUI-5386).
* `RadioList`'s `required` attribute is correctly applied when inside a `ControlGroup` (SUI-5386).

4.24.0 - Jan 9, 2024
----------
New Features:
* `Breadcrumbs` now supports `enableCurrentPage` which enables the current page link (SUI-5910).

Bug Fixes:
* Disabled `Option`s for `ComboBox` and `Search` are no longer selectable with keyboard navigation (SUI-5905).
* Fixed a `styled-components` specificity issue where `Table`'s cursor would incorrectly be set to `pointer` in some cases (SUI-5914).
* `TabBar` no longer shows a duplicate browser tooltip (SUI-5916).

4.23.0 - Dec 5, 2023
----------
New Features:
* Added `expandChildrenOnShiftKey` prop to `JSONTree` (SUI-5771).

Bug Fixes:
* The system color picker for `Color` no longer closes unexpectedly during color selection in Safari (SUI-5831).
* `ComboBox`'s options are no longer clickable while closing (SUI-5825).

Deprecations:
* `JSONTree`'s `expandChildren="withShiftModifier"` value has been deprecated and will be removed in a future major version. Use the `expandChildrenOnShiftKey` prop instead (SUI-5771).

Docs:
* Examples have been updated to use sentence case instead of title case to align with the Splunk Styleguide (SUI-5814).

4.22.1 - Nov 14, 2023
----------
Bug Fixes:
* `Message` should now allow containing elements to be styled to take up the full width of the container (SUI-5843).
* `ComboBox`, `Date`, `Number`, `Search`, `Text`, and `TextArea` should now provide `name` and `value` to the `onFocus` and `onBlur` callbacks (SUI-5844).
* `List` will not incorrectly warn for the `type` prop (SUI-5845).

4.22.0 - Nov 7, 2023
----------
New Features:
* `Color` Enterprise theme includes toolbar from Prisma theme. (SUI-5803).

Bug Fixes:
* `Menu`'s `hasSubmenu` icon uses `ChevronRight` in prisma theme now (SUI-5791).
* Disabled `RadioBar.Option`s are no longer selectable with keyboard navigation (SUI-5804).
* `Slider`s with `step` prop respects `min` and `max` values that are not multiples of the `step` value (SUI-5796).
* `Select` should no longer throw a "maximum update depth exceeded" error in certain situations (SUI-5834).
* `TabBar` in vertical mode does not change widths when focused (SUI-5782).
  * Padding between count and label has been adjusted.
* `Table` column widths are prevented from shrinking below 60px wide when using the `resizableFillLayout` prop (SUI-5484).

Docs:
* `Button` and `Select` examples now have icon size parity (SUI-5757).

4.21.1  - October 11, 2023
----------
Bug Fixes:
* This package should now load correctly in Webpack 4 environments (SUI-5802).


4.21.0 - October 4, 2023
----------
New Features:
* `Link` supports type `string` for `openInNewContext` to customize the default message (SUI-5784).

Bug Fixes:
* Swapped the styles of `Heading`'s `level=5` and `level=6` so that font sizes are ordered correctly (SUI-5668).
  * Note: To continue using the original level 5 styles use level 6 instead and vice versa.
* `Link` now correctly informs users when a link will open in a new window in Prisma themes (SUI-5784).
* `Link` has updated screen reader text better describing the `openInNewContext` behavior to users (SUI-5784).
* `Message` now has increased spacing between icon and text in Prisma themes for `appearance="fill"` (SUI-5755).
* `Message`'s padding, border, and icon alignment have been adjusted to now match the Splunk Design System (SUI-5524).
* `TabBar`'s `count` prop is now properly announced to screen readers (SUI-5754).

Docs:
* Added missing documentation for `Markdown`'s `elementRef` prop (SUI-5621).

4.20.0 - September 5, 2023
----------
New Features:
* New `Breadcrumbs` component (SUI-1819).
* `Code` now supports `language="splunk-spl"` (SUI-5737).

Bug Fixes:
* The loading spinner and loading message in `Select` no longer overlap (SUI-5576).
* `Popover` handles resize and scroll events only when it's open to improve performance (SUI-5670).
* Updated `Multiselect` and `Select` components to reduce rerenders (SCP-65071).
* `Tooltip` and `Popover` no longer detach from the anchor with pinch-to-zoom in Safari (SUI-5408).

Deprecations:
* `Concertina` has been deprecated and will be removed in a future major version (SUI-5741).

4.19.0 - August 1, 2023
----------
New Features:
* Heading now supports `elementRef` (SUI-5534).
* `Multiselect` with `compact` displays "Select all/Clear all" as an option when `selectAllAppearance="checkbox"` (SUI-5607).

Bug Fixes:
* The `TabBar` tooltip now aligns to the center of the `Tab` in Prisma theme (SUI-5598).
* Clicking the "clear" button in `ComboBox`, `Multiselect.Compact`, `Search`, `Select`, `Text`, and `TextArea` will no longer cause focus to be lost (SUI-5667).
* Updated `Chip`'s background-colors and text-color to fix contrast failures in Enterprise theme (SUI-2836).
* `Multiselect` with `compact` should no longer take `disabled` or new options into account when determining if "Select All" or "Clear All" should be enabled (SUI-5645).

4.18.0 - July 12, 2023
----------
New Features:
* Added `ordered` prop to `List` component (SUI-5550).

Bug Fixes:
* `Number` Typescript now accepts `inputRef` prop to target the underlying text input.
* `Number` and `Text` components' focus methods now accept focus options.
* `TabBar` and `TabLayout` no longer renders `[object Object]` in the tooltip when `label` is a `React.Node` (SUI-5352).
* `Menu.Item` sets the correct size for svg elements passed to the `icon` prop in prisma themes.

Deprecations:
* `Heading`'s `level="s"` and `level="ss"` have been deprecated and will be removed in a future major version. See the migration guide for details (SUI-5536).
* `List`'s `type` prop has been deprecated and will be removed in a future major version (SUI-5551).
  * List will default to `HTMLUListElement`. Use `ordered` prop to set list to `HTMLOListElement`.
  * Use CSS to style the `list-style-type` property.

4.17.1 - June 6, 2023
----------
Bug Fixes:
* `Multiselect` should respect `aria-label` and `labelledBy` props (SUI-5510).
* Fixed incorrect `aria-*` and `role` attributes in `Select` (SUI-5515).
* `Multiselect` and `ComboBox` now indicates an option is a new value (SUI-5541).
* `Message` now has reduced spacing between icon and text (SUI-5448).
* Fixed incorrect `role=status` and required aria attribute in `Multiselect` (SUI-5517).
* `Select` now has correct focus behavior when it has a filter, above placement, and an empty value (SUI-5525).
* Fixes an issue where the "close" buttons in `SideNav`, `FormRows`, `Modal`, and `SidePanel` were missing accessible names in version 4.17.0 (SUI-5566).

API Changes:
* Added support for the latest `styled-components@5` (SUI-5467).

Deprecations:
* `TextArea`'s `canClear` prop has been deprecated. If the "clear" action is required, we recommend implementing it via an adjacent "clear" button. (SUI-5306).

4.17.0 - May 10, 2023
----------
New Features:
* Updated `@splunk/react-icons` dependency to v4:
  * Components with icons in Prisma themes previously used private icons.
  * These icons have been replaced with the icons from `react-icons`.
  * Note: this may cause slight visual changes to align the components with the design system.
* `Code` will no longer throw an error with an invalid `language` prop, and will fall back to `javascript` instead. The fallback language can changed with the new `languageFallback` prop (SUI-5425).
* `TabBar` and `TabLayout` support `layout="vertical"` in Prisma themes (SUI-2777).
* New `DualListbox` component for listbox multi-selection (SUI-4251).
* Added `level`s 5 and 6 to `Heading`; `level={5}` maps to `h5` and `level={6}` maps to `h6`.
* `Typography` supports a new `variant` prop for styling (SUI-5286).
* Added `inline` prop to `SplitButton` (SUI-5388).
* `SplitButton` supports `appearance="destructive"` in Enterprise themes (SUI-5395).
* Added new test hooks to `File` for disabled (`[data-test-disabled]`) and error (`[data-test-error]`) states.
* Added new test hook to `File.Item` for the error state `data-test-error`.

Bug Fixes:
* `Markdown` no longer crashes when syntax is invalid for code blocks (SUI-5425).
* `Menu` keyboard navigation has been fixed when `Menu.Divider`, `Menu.Heading`, or `Menu.Item` are a styled component (SUI-5159).
* `RadioBar` should no longer become keyboard inaccessible if an invalid value is passed (SUI-5434).
* `Multiselect`'s border color when `disabled` now matches the border color of other data entry components (SUI-5426).
* Updated warning type `MessageBar`'s text color to improve contrast ratio (SUI-5310).
* Updated `TabBar`'s count background color to improve contrast ratio across different backgrounds (SUI-5274).
* `Tab` no longer throws error for custom data-test props (SUI-5373).
* Fixed slight vertical misalignment of `Message`'s icon with text.
* `Menu` no longer unnecessarily recomputes the `onFocus` handler of `Item` (SUI-5369).

Type Changes:
* `Table`'s `HeadInner` prop now has more accurate typing for `sortDir`.
* `Image`'s `ImagePropBase` type now has its `error` prop marked optional to match the component props.

4.16.3 - March 7, 2023
----------
Bug Fixes:
* `Tooltip` should no longer cause its container to overflow when shown (SUI-5345).
* `Tooltip` should no longer be read twice by screen readers (SUI-5318).
* `Multiselect`'s `required` attribute is now only set when `required` prop is `true` (SUI-5366)

Deprecations:
* `Typography` no longer supports numerical values for `weight`. Instead use the key-word values (SUI-5344).

Typescript:
* `Typography` no longer exports the type `AllTypographyParams`.

4.16.2 - January 26, 2023
----------
Bug Fixes:
* Revert usage of pre-release `@splunk/react-icons` features.

4.16.1 - January 25, 2023
----------
Bug Fixes:
* Fixed `Multiselect` placeholder text with `prisma` theme to be vertically centered  (SUI-5303).
* `Select` and `Multiselect` now can be opened with the up and down arrow keys (SUI-3527).
* Updated `ControlGroup` to fix `labelPosition="top"` misalignment in Prisma themes (SUI-5278).
  * Note: this may cause slight layout changes for existing usages of `ControlGroup`.
* `axe-html-reporter` no longer incorrectly listed as a dependency.

4.16.0 - January 10, 2023
----------
New Features:
* Added `data-test` selectors to `File` (SUI-5205).
* Added `primaryColumnIndex` prop to `Table` and `rowScreenReaderText` prop to `Table.Row` to improve screen reader usability of selectable rows (SUI-5044).
* `Button` supports `appearance="destructive"` in Enterprise themes (SUI-5082).
* `TabLayout` supports `count` prop (SUI-5080).
* `Typography`'s `color` prop now supports `inherit` option.

Bug Fixes:
* `Select`, `Button`, `RadioBar`, `ButtonGroup` error state background color has been updated in enterprise themes to improve contrast (SUI-5082).

Deprecations:
* `Button`'s `error` prop has been deprecated and will be removed in a future major version. Use `appearance="destructive"` instead (SUI-5082).


4.15.0 - December 6, 2022
----------
New Features:
* Added a `required` prop to `ControlGroup` to support inputs being required (SUI-5108).
* Added support for a `filter` prop to `Multiselect` in `compact` mode (SUI-5201).
  * This property supports `true`, `false`, and `"controlled"` as values, similar to `Select`.
  * If this is set, the `controlledFilter` prop is ignored because `filter="controlled"` has identical functionality.

Bug Fixes:
* Added missing type definition files for `TextArea` and `Divider` (SUI-5154).
* Fixes missing `data-test="fixed-head"` test hook in `Table` (SUI-5157).
* Added SSR support for `Select`
* Optimizes bundle sizes of consumers by reducing footprint of "lodash" (SUI-5090).
* Added a missing icon for `openInNewContext` in `Menu.Item` (SUI-5165).
* `Menu.Heading` no longer has an extra padding in Prisma themes (SUI-4114).
* `Color` will render a console warning when an invalid Hex value is supplied (SUI-5081).
* Pins `react-spring` to v9.2.4 (SUI-5170).
* Upgrades `moment` to v2.29.4 and `minimist` to v1.2.6 (SUI-5176).
* `Popover` and all elements derived from it no longer accept mouse input during their disappear animation (SUI-3543).
* `Tooltip` is no longer interactible during its disappear animation (SUI-5116).
  * The default `closeDelay` has been increased from `0` to `300`.
  * The disappear animation duration has been correspondingly reduced.
  * This allows for a grace period when the user can leave and return to the `Tooltip`.
  * This is similar to the old disappear behavior, but without the issue where a mostly-invisible tooltip accepts mouse interaction.
  * `onRequestOpen` and `onRequestClose` callbacks will no longer trigger when the mouse moves between the `Tooltip` `anchor` and `Popover`.
* `Date` now shows the correct cursor type along the outer edge of the input when disabled.

4.14.0 - November 1, 2022
----------
New Features:
* New `Divider` component for separating components with horizontal or vertical rules (SUI-4080).
* Added `inputOnly` prop to `Date` for Prisma theme (SUI-3809).
* Added a `renderChildrenWhenCollapsed` prop to `CollapsiblePanel` and `TransitionOpen` which defaults to `false` (SUI-4321).
* Added a `divider` prop to `Modal` to show dividers between header, body and footer. The value defaults to `both` (SUI-3443).
* `ControlGroup`'s `error` prop now takes `boolean` or `string` (SUI-5086).
  * `error` with `string` will display error text below the control.
  * `help` and `error` text can be displayed at the same time.

Bug Fixes:
* `Date`'s dropdown menu is now keyboard accessible (SUI-3809).
* `Text` now allows the `role` to be set externally.
* `ControlGroup` will no longer hide its `Tooltip` on toggle click (SUI-5116).
* Server side rendering support is now added for `ScrollContainerContext` and `Table` (SUI-5115).
* `Card`'s `title` and `subtitle` now wrap/truncate correctly when `actionPrimary` or `actionsSecondary` are present (SUI-5096).
* `Modal` shows dividers by default for the Prisma theme to match the Splunk Design System (SUI-3443).

4.13.0 - October 5, 2022
----------
New Features:
* New `SplitButton` component (SUI-2760).

Bug Fixes:
* `Button`s visual design now matches the Splunk Design System (SUI-3072).
* `Table` now displays the full drag handle when using `headType="fixed"` and `HeadDropdownCell` (chore).
* `Text`'s and `TextArea`'s adornment color now match the Splunk Design System (SUI-5076).
* Improved `Menu` keyboard navigation performance with large data sets.
* `Multiselect` with `compact` will no longer affect disabled items with "Select All" and "Clear All" (SUI-5060).

Deprecations:
* The `placeholder` prop in the `Text`, `TextArea`, and `Number` components has been deprecated and will be removed in the next major release (SUI-5055, SUI-5095).
    * `placeholder` text presents a number of visual and cognitive issues and best to avoid using it.
    * The HTML `placeholder` attribute is still supported.
    * The `placeholder` attribute should not replace a label.

4.12.1 - September 20, 2022
----------
Bug Fixes:
* `Text` now only displays the "clear" icon if a value has been entered (SUI-3735).
* `Heading` no longer transforms text to be uppercase (SUI-5074).
* `Menu.Heading` no longer transforms text to be uppercase (SUI-5074).

4.12.0 - September 6, 2022
----------
New Features:
* Added a new `Typography` component for styling text content (SUI-3665).
* Added an `onScroll` prop to `ComboBox`, `Multiselect`, `Search`, and `Select` (SUI-4309).
* Added a new `TextArea` component for multi-line text input (SUI-4075).

Bug Fixes:
* `ComboBox`, `Multiselect`, and `Select` will no longer call `onScrollBottom` twice when the whole menu fits on-screen (SUI-2776).
* `Text`'s value cannot be cleared when `disabled` (SUI-4276).
* Allow line breaks when using `Text`'s `multiline` prop (SUI-4013).
* `Table`'s header has been refactored:
    * Now using `position:sticky` from `headType="fixed"`
    * Scroll bar no longer displays beneath the header when using `headType="fixed"` (SUI-1503).
    * Toggle action no longer receives focus twice when using `headType="fixed"` (SUI-1849).
    * Header cell offsets no out of sync when using `headType="fixed"` and asynchronously loaded images/canvas (SUI-2580).
    * Header no longer disappears when using `headType="fixed"`, `onRequestResizeColumn` and `resizableFillLayout` (SUI-3263).
    * Header cells widths no longer out of sync when using `headType="fixed"`, `onRequestResizeColumn` and `resizableFillLayout` (SUI-3417).

Type Changes:
* `ComboBox`, `Multiselect`, and `Select` now have more accurate typing for `onScrollBottom` (SUI-2776).

Deprecation:
* `Text`s `multiline`, `rowsMax`, and `rowsMin` props are deprecated and will be removed in a future major version. Use the `TextArea` component for free-form text input instead (SUI-4075).

4.11.0 - August 2, 2022
----------
New Features:
* Added a `separateStackingContexts` prop to `LayerStackGlobalProvider`. This allows multiple "floating" elements (such as a `Popover` and a `Modal`) to stack in the order that they were opened rather than a fixed order (SUI-2809).
    * This prop is currently defaults to `false`, to be backwards compatible, but will default to `true` in the next major version.
* Added util `prepareSandboxCode` to parse imports for including additional files to CodeSandbox examples.
* `ControlGroup` now supports customizing the position of the tooltip via the `tooltipDefaultPlacement` prop (SUI-3041).

Bug Fixes:
* `Text` no longer holds space for the clear icon when it is not shown (SUI-3748).
* Fixed `Text`'s error border color to stay the same when hovered on error (SUI-3672).
* `Tooltip` will now hide when the toggle is clicked (SUI-3453, SUI-2712).
* Fixed `MessageBar` content to be centered when persistent (SUI-3561).

Type Changes:
* Fixed `Sidebar` type definition to allow props that are passed to `TransitionOpen` (SUI-4253)

4.10.0 - June 29, 2022
----------
New Features:
* Changed `Paginator`'s `PageSeparator` to have active color for Enterprise theme (SUI-3237).
* Added `expandChildren="withShiftModifier"` prop to `JSONTree` (SUI-3627).

Bug Fixes:
* `RadioBar` supports keyboard navigation using the arrow keys (SUI-3745).
* Fixed line-height for `Code` in Prisma themes (SUI-3637).
* Fixes `RadioBar.Option` spacing when using adornments in Enterprise themes.
* `File` descriptive button text now includes an ellipsis.
* Fixed animation toggle issue with `SlidingPanels` by bumping `react-spring` version (SUI-3474).
* Fixed life cycle warnings for components leveraging the `onRest` on `react-spring` (SUI-3666).
* Updated `ComboBox` to fix menu misalignment (SUI-3622).
* Added support for removing `Card.Body` padding via the `inset` prop (SUI-3704).

4.9.0 - June 7, 2020
----------
New Features:
* `MarkdownAnchorHeading` added to Markdown's renderers to allow headings as Anchors (SUI-831).

Bug Fixes:
* Clear button for `Text` now clears value on Safari (SUI-3510).

4.8.0 - May 20, 2022
----------
New Features:
* Added `startAdornment` and `endAdornment` props to `RadioBar.Option` (SUI-3505).

Deprecation:
* `RadioBar.Option`s `icon` prop is deprecated and will be removed in a future major version. Use `startAdornment` or `endAdornment` instead (SUI-3505).
* `RadioBar`s `appearance` prop is deprecated and will be removed in a future major version (SUI-3505).

4.7.0 - May 4, 2022
----------
New Features:
* New `MessageBar` component for system-level messages.

Bug Fixes:
* `Modal` now has the correct border radius and the `icon` in `Modal.Header` is now centered (SUI-3447).
* `Switch` checkbox no longer displays the default browser tooltip. The default values of `selectedLabel`, `someSelectedLabel` and `unselectedLabel` of `Switch` have been removed (SUI-3241).
* `Switch` checkbox status is no longer read twice by screen reader (SUI-3241).
* `Menu.Item`s with icons have the correct height of 40px and icons are vertically centered (SUI-3341).
* `Modal.Body` now has the correct text color of `contentColorDefault` in Prisma themes (SUI-3488).
* `Select`'s options should no longer be clickable while it's collapsing (SUI-3337).
* `Menu`s should now correctly manage focus if the first item is disabled (SUI-3468).
* `Message`'s `appearance="banner"` renders with an icon for improved accessibility (SUI-3526).
* `Modal` will now correctly gain focus when created with `open=true` (SUI-3412).

Deprecations:
* `Message`'s `appearance="banner"`is deprecated and will be removed in a future major version. Use `MessageBar` instead (SUI-3437).
* `Message.Link` is deprecated and will be removed in a future major version. Use `Link` instead (SUI-3322).

4.6.0 - April 5, 2022
----------
New Features:
* Updated the `File` uploader descriptive button text from `browse...` to `upload file` (SUI-3275).
* `Clickable` now supports the `navigationLabel` prop to provide `data.label` to the `onClick` handler (SUI-3123).
* Added `onInputClick` prop to `Text` component (SUI-2801).

Bug Fixes:
* `NavigationProvider`'s `value` **now** has the the same shape as other provider values.
* `TransitionOpen`'s slide transitions now consistently use transforms instead of animating dimensions (SUI-3328).
* `FormRows`'s inside a `Modal` now display correctly when being sorted (SUI-3416).
* Focus on `FormRows` drag handle is now visible in Prisma themes (SUI-3415).
* `Modal`'s title is now read by screen reader.
* `Card` will no longer render with different dimensions depending on the combination of `to` and `onClick` props.
* `TableRow`'s `data` prop is no longer incorrectly passed to the DOM element (SUI-3448)

4.5.3 - March 15, 2022
----------
Bug Fixes:
* Fixed a regression where `Accordion.Panel`s may not open (SUI-3411).

4.5.2 - March 8, 2022
----------
Bug Fixes:
* Pinned `styled-components@5.1.1` to avoid breaking changes introduced in `styled-components@5.2.0`.

  **`@splunk/react-ui` is incompatible with styled-components version(s) `^5.2.0`**.

  `styled-components@5.2.0` changed how selectors like `& + &` are compiled; [styled-components PR#3236](https://github.com/styled-components/styled-components/pull/3236).
  This breaks styles that worked in previous versions of styled-components; [styled-components issue #3265](https://github.com/styled-components/styled-components/issues/3265).

  **Until noted otherwise in a future release of `@splunk/react-ui` do not use `styled-components@^5.2.0` with` @splunk/react-ui`**.

4.5.1 - March 1, 2022
----------
Bug Fixes:
* `DefinitionList.Term`'s color uses `contentColorMuted` to align with design specification (SUI-3287).
* Fixed a layout regression for `RadioBar` in Enterprise themes (SUI-3303).
* Fixed `Button` not rendering `role` prop when provided (SUI-3303).
* `RadioBar` buttons have `role="radio"` in Enterprise themes (SUI-3303).

4.5.0 - February 23, 2022
----------
New Features:
* `FormRows` can now be rendered without the Add/Remove buttons by omitting the `onRequestAdd` and `FormRows.Row`'s `onRequestRemove` props.
* `File` supports customizing the supports message via a new `supportsMessage` prop.
* `File`'s `help` prop is now supported in enterprise themes and when `fullscreen` is disabled.
* A new `Search` component has been added. This component behaves like `Text` with `appearance="search"`, but supports an options dropdown.
* `Modal` has a new `initialFocus` prop to customize where focus is placed when the modal opens: `first` (first focusable element in the modal), `container` (focus the modal itself), or a ref (SUI-2814).
* `ControlGroup`'s cloned props `id` and `inputId` are now cached when not provided (SUI-2817).
* `Color`'s `defaultPalette` is now extrapolated from 8 base colors by `tinycolor2` to form the rest of the palette (SUI-2466).
* Redundant `Table.HeadCell` indicators for sortable columns in Prisma themes have been replaced with the icons that matches the existing sort arrows. Note: column widths may be affected by this change (SUI-2547).
* `Table` now supports `rowExpansion="controlled"` to allow for customization of expanded row state (SUI-2649).
* `Select` now supports jumping to the first matching item when a character key is pressed as long as `filter=false` and the control is not currently loading data. This behavior can be disabled with `allowKeyMatching=false`

Bug Fixes:
* Updated `Chip` styles to grid to fix misalignment (SUI-2706).
* `Multiselect.Compact` now supports the `showSelectedValuesFirst` property to control if selected items are moved to the top of the list on `nextOpen` (default), `immediately`, or `never`.
* `TreeNode` would not render `:` separating key/value pairs in some cases, this has been fixed.
* `TabBar` no longer shifts upon selection in Prisma themes (SUI-2821).
* `Color` no longer throws warning when selecting a `null` value (SUI-2437).
* `Popover` no longer ignores the `pointTo` prop in Prisma themes (SUI-2750).
* `RadioBar` no longer has uneven padding when it is icon only (SUI-2782).
* `Message` Banner appearance info status is now white instead of grey (SUI-2811).
* `TabBar` keyboard navigation has been fixed to circle through tabs, skipping the disabled tab (SUI-2774).
* `Table.Row`'s `onClick` prop will no longer trigger when clicking on the row expansion button, the primary action button, or the secondary action button (SUI-2631).
* `Multiselect` now supports the `repositionMode` property to determine if and how the `Popover` repositions itself using `flip` (default) or `none` (SUI-1716).
* Disabled `Text` no longer has `[data-test="disabled-textbox"]` and should instead be selected as `[data-test="textbox"][disabled]` (SUI-2447).
* Updated `Select.Option` to fix check icon vertical alignment (SUI-2803).
* `Select` should now pass the correct value to `onFilterChange` when opened rather than an empty string (SUI-3234).
* `Multiselect` should now correctly clear the filter on open when `compact` is set (SUI-3234).
* `Combobox`, `Multiselect`, `Search` and `Select` will no longer lose reset their scroll position when new items are added (SUI-3233).
* `Color`'s text entry box will no longer overflow its container in the Prisma theme (SUI-3253).

Type Changes:
* `ScrollContainerContext`'s type replaced `"window"`with `window`, `Element` with `HTMLElement` and the default value changed to `window` (SUI-2839).

Deprecations:
* The `useSyntheticPlaceholder` prop in the `Text` & `Number` components has been deprecated (SUI-2583) and will be removed in the next major release (SUI-2820).
* The `xlarge` option in the `size` prop of the `Monogram` component has been deprecated (SUI-3221) and will be removed in the next major release (SUI-3222).

4.4.1 - October 19, 2021
----------
Bug Fixes:
* Select will start controlled if `value` is `undefined`, maintaining previous 4.x behavior (SUI-2772).

4.4.0 - October 4, 2021
----------
New Features:
* `Table` can fill its container and support resizable, auto-sized columns with the new `resizableFillLayout` in enterprise themes (SUI-2546).
* `Text` now supports `startAdornment` and `endAdornment` to allow for customization with icons and actions (SUI-2682).
* `Text` has an improved label with better context for its "Clear" button (SUI-2696).

Bug Fixes:
* Updated `prismjs` dependency to address vulnerability (SUI-2757).
* `Scroll` no longer requests undeclared dependency `@react-spring`.
* `Text` no longer loses focus after clearing text using the Clear button (SUI-2761).
* Updated `Chip` styles to grid to fix misalignment (SUI-2706).

4.3.0 - September 8, 2021
----------
New Features:
* `Text`'s "clear" button is now able to receive keyboard focus (SUI-2626).
* `Multiselect` is correctly focused when its label is clicked (SUI-2052).
* `Multiselect` supports `inputId` prop (SUI-2052).
* `Text`'s `type` prop now supports `time` (SUI-2716).
* `Menu.Header` supports `outerStyle` prop (SUI-2727).
* `CollapsiblePanel`'s `innerBodyStyles` prop is now public (SUI-1701).
* `Text`, `Button` and related component's border color updated to meet contrast requirements in Enterprise Light theme (SUI-2613).
* `Multiselect` color updated to meet contrast requirements (SUI-2636).
* `JSONTree`'s `onClickKey` prop added (SUI-2452).

Bug Fixes:
* `Table` expandable row and draggable row no longer shrink when table is shrunk (SUI-2413).
* `Text`no longer shows "clear" button in Prisma themes during error state without focus (SUI-2626).
* `Paginator` accessibility improved by updating semantics and setting the role for ellipsis to separator (SUI-2499).
* `Text` no longer displays current value in `data-test-value` test hook when `type="password"` (SUI-2622).
* `ComboBox`, `Select`, and `Multiselect` no longer incorrectly display a second focus border on the active list item (SUI-1678).
* `Progress` had content duplicated for non-visual users (SUI-2635).
* Fixed the regression of `Color`: the `null` swatch no longer display when the palette does not have the `null` value in Enterprise themes (SUI-2707).
* `Switch` components in a `ControlGroup` with `controlsLayout="fill"` now have the appropriate margin (SUI-1845).
* `Select` and `Multiselect.Compact` will no longer reacquire focus while closing (SUI-2054).
* `Menu` keyboard navigation has been fixed to have correct accessible behavior when `retainFocus="false"` (SUI-2005).
    * `Menu` only has a single tab stop - navigation between items is accomplished with the `up` and `down` keys.
    * This change will affect `Select` and `Multiselect.Compact`, as well as `Menu` inside `Dropdown` and `Popover`.
    * `Menu` inside `Dropdown` and `Popover` will inherit the value of `retainFocus` if one is not explicitly specified.
    * To support this change, a new `tabKey` value has been added to the `closeReasons` for `Dropdown` and `Popover`.
    * `tabKey` has also been added to `focusToggleReasons` for `Dropdown` and `Popover`.
    * Components overiding `closeReasons` or `focusToggleReasons` may need to add `tabKey` to maintain expected behavior.
* `Select All` and `Close All` in `Multiselect.Compact` should now be keyboard accessible (SUI-1415).
* `Multiselect.Compact` will now announce when items are selected/unselected (SUI-2733).
* Fixed `Multiselect.Option`'s `Switch` checkbox uneven padding in compact mode (SUI-2730).
* `TabBar` no longer applies props to children when they are not of type `TabBar.Tab`.
* Added error message for invalid anchor values in `Popover` (SUI-2307).

Notes:
* Upgraded `react-spring` to v9.2.2 (SUI-2641).

4.2.0 - June 17, 2021
----------
New Features:
* `Tab` now supports the `to` property to render as a link (SUI-2616).
* `Combobox` supports two new test selectors: `data-test-label` and `data-test-current-value-option` (SUI-2615).

Bug Fixes:
* `Combobox` renders `label` instead of `value` when an option is selected (SUI-2615).
* `Paginator` buttons no longer overlap in narrow containers (SUI-2558).
* `Multiselect` supports jumping to the beginning and end of the menu using the `home` and `end` keys respectively (SUI-2572).

4.1.0 - May 6, 2021
----------
New Features:
* Enable TS support.
    * The type definition files may have breaking changes between versions until stated otherwise in this Changelog for a future version.
* `Accordion` and `Accordion.Panel` support a new `inset` prop which adds styling to match designs (SUI-2541).
    * This prop is currently defaults to `false`, to be backwards compatible, but will default to `true` in the next major version.
* `Combobox.Option` supports a new `label` prop which can be used for display and matching separate from and instead of `value` (SUI-2535).
* `Text` supports new prop `passwordVisibilityToggle` which allows password visibility to be toggled with an icon button (SUI-2434).

Bug Fixes:
* `Button` no longer uses primary color in active state (SUI-2561).
* `Menu` items selected state is announced correctly by screen readers (SUI-2488).
* `Table`'s column sort icons no longer overlap with the column header text in Enterprise themes (SUI-2543).
* `Tooltip`'s content is announced correctly by screen readers (SUI-2520).
* `Table` now has an improved screen reader experience for selectable row and expandable row (SUI-2517, SUI-2519).
* `Tab` and `TabBar` keyboard navigation has been fixed to have correct accessible behavior (SUI-2468).
    * Navigation between tabs is now accomplished with `left`, `right`, `home`, and `end` keys.
    * In `enterprise` theme with `layout=vertical`, `left` and `right` are `up` and `down`, respectively.
    * A new `autoActivate` prop has been added that will cause tabs to automatically become active when focused.
    * Navigation between individual tabs with the "Tab" key is no longer supported.
    * Active `Tab` components now have bold text.
* `Text`'s placeholder text is no longer excessively cut off by the `canClear` icon's styles (SUI-2564).

4.0.3 - April 5, 2021
----------
Bug Fixes:
* `Color` would error when rendering at runtime, `Color` now uses ui-util to validate hex colors when rendering a swatch (SUI-2555).

4.0.2 - March 31, 2021
----------
Bug Fixes:
* `Popover` and `TransitionOpen` animation performance improved by implementing `react-spring`s `native` prop (SUI-2457).
* `Color` uses util converter to expand shorthand hex color value to the equivalent six-digit hexadecimal value (SUI-2530).
* `Table`, `Switch` color updates to meet A11y_WCAG 1.4.3 contrast requirements in Enterprise themes (SUI-2494).
* `JSONTree` uses new set of colors in Enterprise themes to improve contrast (SUI-2529).
* Fixed a bug where user-input into the `Color` component could affect the rendered swatch in Enterprise themes (SUI-2540).
* `Chip` only renders valid CSS colors for the `backgroundColor` and `foregroundColor` props (SUI-2540).

4.0.1 - March 2, 2021
----------
Bug Fixes:
* Debounce events when selecting `Color`'s custom color by dragging in native color pickers (SUI-2491).
* Fixed an issue where `Color`'s custom color picker would not respond to click events after selection (SUI-2508).
* `Color` no longer warns about deprecated `anchor` prop (SUI-2502).
* `Color`'s custom color is focused on open after minimizing palette (SUI-2501).
* `Dropdown`'s accessibility attributes changed to improve screen reader experience.

4.0 - February 4, 2021
----------
New Features:
* `Button`'s `appearance` prop now supports `destructive` in Prisma themes (SUI-2374).
* `CollapsiblePanel` now supports `titleWithActions` prop in Prisma themes. It allows to add clickable components in panel header (SUI-2366).
* `Color` supports new `hideInput` prop in Prisma themes (SUI-2486).
* `ComboBox`, `Number` and `Text` now display placeholder text when disabled (SUI-2373).
* `File`'s retry button has a new `onRequestRetry` prop in Prisma themes (SUI-2411).
* `Image` now supports `error` prop (SUI-2353).
* `Progress` supports `type` prop in Prisma themes.
* `Slider` supports `error` prop in Prisma themes.
* `StepBar` supports new `error` prop in Prisma themes (SUI-2407).
* `TabBar` has a new `count` prop that inserts a number into the tab label (SUI-2254).
* `Tooltip` has a new `contentRelationship` prop (SUI-1343).
* `WaitSpinner` supports `large` value for `size` prop in Prisma themes. Enterprise themes fall back to `medium` if `large` prop is used.

Bug Fixes:
* `ControlGroup` now has an improved screen reader experience for tooltips (SUI-2318).
* `ControlGroup` with label on left is now vertically centered (SUI-2473).
* `Color` design fixed in Enterprise themes.
*  Primary `Button`'s background color uses new WCAG AA compliant color in Enterprise themes (SUI-2439).
* `Slider` no longer has redundant `aria-value*` content in Tooltip (SUI-1343).
* `Tooltip` screen reader experience improved (SUI-1343).
* `Tooltip`s can be closed by pressing Escape key (SUI-1343).

API Changes:
* `Accordion` no longer supports `collapseAll` prop and all panels are allowed to collapse by default (SUI-2365).
* `Button` and `Select` no longer support the `error` prop in Prisma themes for most `appearance` values. Only `appearance="toggle"` supports displaying an error.
* `Button`, `Chip`, `Color`, `ComboBox`, `Multiselect`, `Number`, `Select`, `RadioBar`, `RadioList`, `Switch` and `Text` no longer have a `size` prop. Use the Compact theme variant to access the smaller appearance.
* `Chip` and `Multiselect.Option` no longer support the `info`, `success`, and `warning` appearances in Prisma themes.
* `Color` exports `isValidHEX` as a named export, it is no longer a class property.
* `File` no longer supports `onRequestRemove` prop with custom children (SUI-2411).
* `File` now supports `fullscreen` prop instead of `size=large` (SUI-2352).
* In `Popover`, passing a React component instance as `anchor` is deprecated. Pass an `HTMLElement` instead (SUI-2204).
* In `Dropdown`, passing a `toggle` that returns a React component instance as `ref` is no longer supported (SUI-2204).
    * Ensure the toggle `ref` is an `HTMLElement`. `Clickable`, `Button`, and `Link` are exempt.
* Internet Explorer 11 is no longer supported.
* `Modal` no longer supports the `enablePeek` prop. The peek feature has been removed (SUI-2069).
* `Table` no longer supports the `firstLastPadding` prop (SUI-2302).
* `Table.Row` and `Card.Header` rename `actionsPrimary` to `actionPrimary` prop since only one primary action is supported (SUI-2446).
* `Popover`'s `appearance` prop now uses `normal` and `inverted` values, instead of `light` and `dark`. `inverted` is only supported in Enterprise themes.
* `Popover`'s `pointerEvents` prop was removed (SUI-2317).
* `RadioList` accessibility improved (SUI-2287):
    * `RadioList` implemented with `input[type="radio"]`
    * Removed `appearance` prop; replaced with `direction` prop which takes `row` or `column`.
    * `RadioList.Option` no longer supports composing children with labelable elements; children must only be phrasing content.
        See updated Composing example for how to use labelable elements in a `RadioList`.
    * `data-test="button"` replaced with `data-test="input"`.
* `Switch` no longer supports the `appearance` prop with value `radio`.
* `Tooltip`s in Enterprise themes on open delay now matches Prisma (300 and 750 for primary and secondary respectively) (SUI-2317).
* `Tooltip` remains open when content is hovered (SUI-2317).
    * `Tooltip` now responds to `mouseEnterPopover` and `mouseLeavePopover`.
    * `Tooltip` no longer supports `closeDelay` prop with a value of `primary` or `secondary`.
* `Tooltip`'s compact prop was removed. Setting `contentRelationship="label"` will create the same appearance in Prisma themes.
* `Popover`'s `pointerEvents` prop was removed (SUI-2317).

3.3.0 - January 11, 2021
----------
New Features:
* `File` now supports `data-test="help"` test hook (SUI-2448).
* `JSONTree`'s `onClickValue` handler returns a `keyPath` property which is an array representation of the `key` property (SUI-2418).

3.2.0 - October 29, 2020
----------
New Features:
* `Code` now supports YAML with language prop of `yaml` or `yml`.

Bug Fixes:
* Updated `prismjs` dependency in `Code` (SUI-2358).
* Fixed missing animation in `Progress`.
* `Date` no longer omits event argument from certain `onChange` handler calls.
* Fixed erroneous prop type warning in `Multiselect`.
* `Table` cell expansion control's label changed to "Expand row" and "Collapse row" (SUI-2142).
* Fixed `Text` crash in jsdom environments (SUI-2428).

3.1.1 - October 6, 2020
----------
Bug Fixes:
* Fixed incorrect `panelId` value in `Accordion` change handler if `collapseAll` is enabled.
* `label` prop now has the same type in `TabLayout` and `TabBar` (SUI-2380).
* `Table` no longer triggers `onClick` event of `Row` when clicking on actions, buttons, or links (SUI-2379).
* `Text` now handles the `maxLength` attribute as expected (SUI-2390).
* Fixed incorrect `elementRef` value in `Monogram` if `onClick` is provided.

3.1.0 - August 31, 2020
----------
New Features:
* `Number` now supports a `locale` prop (SUI-1470).
* `Select`, `Multiselect`, and `ComboBox` now support `onOpen` and `onClose` props (SUI-2041).

Bug Fixes:
* Screen readers no longer read "row selected" multiple times on `Table` rows with a checkbox (SUI-1912).
* `Code` no longer uses ES6 keywords (SUI-2290).
* `Menu` label and description correctly wrap when used with an icon. (SUI-2212)
* `Color` `Swatch` now updates border and border radius when apply `append` and `prepend` props (SUI-2232).
* `Popover` with `none` appearance no longer causes placement crash (SUI-2271).
* `Collapsible` with `description` now has a space separating the label (SUI-2311).
* `Table` header text no longer overlaps when `truncate` prop is false (SUI-2300).
* `Table` row expand now has hover effect over entire cell in `scp` themes (SUI-2314).
* `Image` now correctly renders a `Message` component with the filled appearance when in the error state (SUI-2355).

3.0.0 - July 7, 2020
----------
New Features:
* New `scpLight` theme (SUI-2099).
* Visual improvements for the `scp` theme.
* Support for `styled-components@^5`.
* Added `ScrollContainerContext` and `ScrollContainerProvider` (SUI-2063).
* `Modal.Body` and `Scroll` now become the default scroll containers for their children (SUI-2063).
* The `elementRef` and `inputRef` props now support object refs (SUI-1910).
* Added `useAnimationToggle` hook to `AnimationToggle`.
* `Text` now supports the `autoCapitalize`, `autoCorrect`, and `spellCheck` props (SUI-2023).

Bug Fixes:
* `AnimationToggle` now disables animation if user prefers reduced motion.
* `Progress` and `SlidingPanels` were ignoring animation settings.
* Disabled text correction in `Color`, `ComboBox`, `Date`, `Multiselect`, `Number`, and `Select` (SUI-2023).
* Fixed inconsistent `value` prop type in `Select.Option` (SUI-1589).
* `Modal` now is in a fixed position near the top of the window in the `scp` theme (SUI-2108).
* `Modal` now focuses on the first focusable element on open, not the container (SUI-2006).
* `Popover` with a scroll container no longer ignores window resize events (SUI-1948).
* `Popover` with a scroll container now closes when the anchor is scrolled off the screen (SUI-1848).
* `Popover` now prefers the downward position even when there is more room above (SUI-2080).
* `Dropdown` no longer ignores a `ref` prop on its toggle.
* Fixed misaligned checkboxes in `Multiselect` (SUI-1966).
* Focus styles are updated in `enterprise` and Splunk Light `lite` themes to improve accessibility (SPL-188569).
* `Select` with an appearance of `link` now has a smaller caret icon.
* `Table` checkbox now is vertically centered (SUI-2242).

API Changes:
* The `react` and `react-dom` peer dependencies are now `^16.8`.
* The `styled-components` peer dependency is now `^5.1`.
* Polyfill requirements for IE11 have changed. For details, see `README.md`.
* `AnimationToggle` no longer supports feature flags.
* `AnimationToggle` renders `off` instead of `on` if user prefers reduced motion and `reduced` prop isn't set.
* Removed `disabled` prop from `AnimationToggleProvider`. Use the `enabled` prop instead.
* Changed the `autoComplete` prop type in `Text` from boolean to string.
* Changed the `value` prop type in `Select.Option` to match `Select`.
* Removed the default value of the `autoComplete` prop in `Text`.
* Removed `Logo` component.
* Removed `scrollContainer` prop from all components. Use `ScrollContainerProvider` instead.
* Removed `fill` prop from `Message`. Use the `appearance` prop instead.
* Removed `data-portal-layer` test hook from `Layer`. Use `data-test="layer"` instead.
* Removed `defaultIcon` prop from `Tooltip`.
* `Dropdown` no longer adds a wrapper div around `toggle`.
    Place `style`, `className` and other props directly on the toggle instead (SUI-1982).
* Removed `inline` prop from `Dropdown`. Modify the toggle instead (SUI-1982).
* Removed `toggle` test hook from `Color`, `Dropdown`, `Select`, and `Multiselect` (compact).
    Use the root selectors instead (SUI-1982).

2.17.0 - May 1, 2020
----------
New Features:
* `Code` now supports `typescript`, `ts`, `tsx`, `jsx`, and `json`.
* `ComboBox` now supports a `scrollContainer` prop (SUI-1914).
* Fixed a localization issue of multiple screen reader content messages (SUI-2057).
* `Popover` now supports a `pointerEvents` prop (SUI-1965).

Bug Fixes:
* Fixed a test issue with multiline `Text` (SUI-1943).
* Corrected the font in `Text` (SUI-1973).
* An empty description in a `DefinitionList` now renders as expected (SUI-1511).
* Mouse events are no longer triggered or propagated from `Tooltip` content (SUI-1965).
* Fixed inconsistent cursor issue in clickable `Card` (SUI-1692).
* Fixed `Switch` misalignment issue in a `ControlGroup` in the `scp` theme (SUI-2067).
* Fixed `Switch` misalignment issue in a flex container in the `scp` theme (SUI-1927).

2.16.0 - March 15, 2020
----------
New Features:
* Added `Layer` component.
* `ButtonGroup` and `RadioBar` now have new styles in the `scp` theme (SUI-1900).
* `Message` now supports the `appearance` and `onRequestRemove` props (SUI-2001).
* Added banner appearance and `Message.Link` component to `Message` (SUI-2001).

Bug Fixes:
* Fixed accessibility issue in `Card`, `CardLayout`, `Modal`, and `Popover` and components using it (SUI-2042).
* Fixed `Chip` style issues in the `scp` theme (SUI-2039).
* Fixed `TabBar` style issues in the `scp` theme (SUI-2024).
* `Paginator` no longer places current page off-center (SUI-1907).
* Fixed `Select` warning for using the `flat` appearance.
* Reverted `Message` default appearance in the `scp` theme (SUI-2047).

2.15.0 - February 5, 2020
----------
New Features:
* Added `Table.Caption` component (SUI-1988).
* `Date` now supports a `highlightToday` prop (SUI-1915).
* `CollapsiblePanel` now supports an `overflow` prop (SUI-2028).
* `Tooltip` now supports a `compact` prop in the `scp` theme (SUI-2025).
* `Message` now has new styles in the `scp` theme (SUI-2000).
* `Slider` now has new styles in the `scp` theme (SUI-2002).
* `Monogram` now has new styles in the `scp` theme (SUI-1938).
* `Paginator` now has new styles in the `scp` theme (SUI-2031).

Bug Fixes:
* The `Dropdown` with icon-only toggle no longer shrinks in a flex container (SUI-1972).
* `Color`, `ComboBox`, `Multiselect`, and `Select` now have an `aria-label` on `Text` inputs (SUI-1987).
* `Menu` no longer filters out the `title` next to a divider (SUI-1978).
* `Text` now handles the `title` attribute as expected.
* Fixed an accessibility issue in `Date` (SUI-1988).
* `Multiselect` calls `onFilterChange` when user clicks away (SUI-2021).
* Fixed `Popover` placement crash (SUI-2022).

2.14.0 - December 23, 2019
----------
New Features:
* `ControlGroup` now supports a `labelFor` prop. `Date`, `Dropdown` and `Select` now support an `inputId` prop.
* `Tooltip` now supports `openDelay` and `closeDelay` props (SUI-1847).

Bug Fixes:
* `Multiselect` no longer ignores the `className` prop (SUI-1967).
* Fixed a label selection issue in `ControlGroup` (SUI-1889).
* Fixed `Multiselect` and `Chip` style issues in the `scp` theme (SUI-1902).
* Fixed a clickable `Card` hover style regression (SUI-1984).

2.13.2 - November 8, 2019
----------
Bug Fixes:
* `Select` no longer passes the `className` prop to children (SUI-1949).
* Title and description of `Menu` items are now aligned in the `scp` theme (SUI-1928).
* Fixed `File` style issues in the `scp` theme (SUI-1942).
* Fixed `Image` style issues in the `scp` and `enterpriseDark` themes (SUI-1941).
* Improved `Date` and `Calendar` styles in the `scp` theme (SUI-1944).

2.13.1 - October 14, 2019
----------
Bug Fixes:
* A fixed `Table` head now updates column widths after a data update (SUI-1909).
* `RadioBar` now uses full width if children are icon-only buttons (SUI-1932).
* Fixed a flex-related IE11 truncation issue in `Button` (SUI-1933).
* Fixed an icon-related IE11 truncation issue in `Button` (SUI-1940).

Notes:
* Relicensed to `Apache-2.0`.

2.13.0 - October 8, 2019
----------
New Features:
* Added `scp` theme.
* `Multiselect` now supports a `tabConfirmsNewValue` prop (SCP-17384).
* `Multiselect.Option` now supports customizing the selected appearance.

2.12.2 - September 12, 2019
----------
Bug Fixes:
* `CollapsiblePanel` using the `defaultOpen` prop now animates with async content (SUI-1752).
* Disabled `Text` with type='password' no longer shows the value (SUI-1872).
* `Select` and `Multiselect` no longer throw an error if `styled-components@^3` is used (SUI-1851).
* Fixed accessibility issues in `Tooltip` (SUI-1840).
* `Multiselect` no longer includes `aria-activedescendant` when there are no options (SUI-1890).
* `DefinitionList` with insufficient width no longer wraps the description.

2.12.1 - August 19, 2019
----------
Bug Fixes:
* `ControlGroup` no longer causes `ref` on children to be ignored.

2.12.0 - August 8, 2019
----------
New Features:
* `Table` now supports reordering rows (SOLNESS-19219).
* `DefinitionList` now supports additional units in `termWidth` prop (SUI-1854).
* `CardLayout` now supports additional units in `cardWidth`, `cardMinWidth` and `cardMaxWidth` props (SUI-1854).

Bug Fixes:
* `Text` no longer renders a clear icon when it is disabled and has a value (SUI-1841).
* `Multiselect` no longer throws an error if `styled-components@^3` is used (SUI-1851).
* Fixed `stopScrollPropagation` in `Scroll` on Chrome (SUI-1855).
* `ControlGoup` with `Switch` as a child no longer throws an error when clicking the label (SUI-1852).

2.11.0 - July 8, 2019
----------
New Features:
* Added `Monogram` component.

Bug Fixes:
* `Select` no longer throws an error if `styled-components@^3` is used.
* `TransitionOpen` no longer sets width to zero if a width is not provided (SUI-1836).

2.10.0 - June 11, 2019
----------
New Features:
* Added `Chip` component (SUI-1762).

Bug Fixes:
* Fixed focus issue in a `Select` without filter and no selected option (SUI-1766).
* The `Image` remove button is now accessible by keyboard (SUI-1736).
* `ControlGroup` no longer throws an error when clicking certain labels (SUI-1817).
* `TransitionOpen` no longer throws an error when animations are disabled and default state is open (SUI-1815).

2.9.0 - April 25, 2019
----------
New Features:
* Most animations can be disabled now (SUI-1210).
* Added `AnimationToggle` component (SUI-1210).
* Clicking `ControlGroup` labels now focuses/toggles certain components (SUI-1690).

Bug Fixes:
* `Tooltip` now closes as expected if moved off-screen (SUI-1689).
* `SidePanel` closing animation now is smooth (SUI-1761).
* `Date` now supports `scrollContainer` prop (SUI-1767).
* Fixed the height calculation of `Text` when `multiline` prop applied (SUI-1755).
* Fixed missing focus outline in `Anchor` (SUI-1795).

2.8.0 - March 14, 2019
----------
New Features:
* `Color` now supports a `N/A` option in the palette (SUI-1693).
* `TransitionOpen` now supports an `outerId` prop.
* `CollapsiblePanel` now supports a `headingLevel` prop (SUI-1700).

Bug Fixes:
* `Code` no longer bundles unsupported language definitions (SUI-1744).
* `Modal` no longer freezes if quickly opened multiple times (SUI-1730).
* `Popover` and components using it no longer close unexpectedly on a mobile device content tap (SUI-1686).
* Fixed `Select` not supporting `describedBy` in a `ControlGroup` (SUI-1738).
* `ControlGroup` now renders correctly when it has conditional children (SUI-1732).
* The ellipsis in `Paginator` had an invalid aria role (MAW-1964).
* Fixed invalid aria role in `Select` button element (SUI-1702).
* A closed `Dropdown` no longer includes `aria-owns` (SUI-1704).
* `Multiselect` input was missing aria properties (SUI-1703).

2.7.0 - February 22, 2019
----------
New Features:
* Support for `styled-components@^4`.

Bug Fixes:
* The shadow input in `Text` is now hidden from screen readers (SUI-1710).

2.6.0 - February 12, 2019
----------
New Features:
* Added `Anchor` component (SUI-1664).

Bug Fixes:
* `Image` and `Number` now work as expected with React 16.4 or newer (SUI-1699).
* The `External` icon in `Button` and `Link` now has a more appropriate tooltip (SUI-1674).
* The default color of `Color` wasn't selectable in controlled mode (SUI-1694).
* A disabled multiline `Text` no longer falls back to default height (SUI-1685).

2.5.0 - January 29, 2019
----------
New Features:
* `Color` now supports a `transparent` option in the palette (SUI-1657).
* `JSONTree` now handles null and empty nested objects/arrays (SUI-1319).
* `Slider` now supports `stepMarks` (SUI-1342).

Bug Fixes:
* `Accordion` no longer animates open on mount (SUI-1665).
* `Date` was missing support for including `name` in `onChange` callbacks (SUI-1680).
* Fixed a layout bug in `SlidingPanel` (SUI-1660).
* `Select` items are no longer clickable while the menu is collapsing (SUI-1663).
* `Number` no longer fails if the `value` prop is set to 0 (SUI-1675).
* `Image` now ignores case when checking file extensions (APPLAT-4382).
* `Text` now inherits height by default (SUI-1662).

2.4.0 - January 2, 2019
----------
New Features:
* `RadioList` now supports an `appearance` prop (SUI-1649).

Bug Fixes:
* `Image` wasn't adapting to container width.

2.3.0 - December 6, 2018
----------
New Features:
* Added `Image` file preview component (APPLAT-3862).

Bug Fixes:
* Fixed `Button` pill appearance hover/focus color in dark mode.
* `Resize` no longer omits `className` (SUI-1652).
* `Text` would break if `multiline` was combined with `appearance` set to `search` (SUI-1608).

2.2.1 - November 15, 2018
----------
Bug Fixes:
* `Switch` was missing a default value for prop `someSelectedLabel` (SUI-1622).

2.2.0 - November 2, 2018
----------
New Features:
* `FormRows` now supports a `disabled` prop (SUI-1595).
* `ControlGroup` now supports a `hideLabel` prop (SUI-1564).

Bug Fixes:
* `RadioBar` options that are both `disabled` and `selected` are now disabled correctly (SUI-1580).
* Fixed `WaitSpinner` clipping (SUI-1341).
* `Table` header cell widths were incorrect in fixed/docked mode (SUI-1297, SUI-1593).

2.1.0 - October 29, 2018
----------
New Features:
* `Select`, `Multiselect` and `ComboBox` now support a `defaultPlacement` prop (SUI-1599).

Bug Fixes:
* Calling `focus` on a `Link` no longer crashes (SUI-1601).
* Fixed `propType` warning for passing JSX as `title` prop to `Concertina.Panel` (SUI-1553).
* `CollapsiblePanel` content no longer overflows horizontally (SUI-1602).
* Fixed `Table` header rendering issue (SUI-1297).
* `Table` with selectable rows and sortable columns now uses the correct drop target.

2.0.0 - September 13, 2018
----------
New Features:
* Support for dark mode.
* Support for dynamic color theming.

API Changes:
* `styled-components` is now a peer dependency.
* The `react` peer dependency is now `^16.3`.
* `CardLayout` children are now required to be `Card`s.
* `Paginator` now displays five pages per default (instead of nine, SUI-1304).
* `Resize` with `border` appearance now renders borders inside of the element instead of outside.

Bug Fixes:
* Content inside of `Resize` is not cropped (SUI-1409).

Notes:
* Theme variable names are not yet considered part of the API. They might change in minor releases.
* Relicensed to `Splunk Software License Agreement`.

1.6.0 - September 5, 2018
----------
New Features:
* `CollapsiblePanel` and `Accordion.Panel` now support a `description`.

Bug Fixes:
* The open `Accordion` panel now scrolls if the `Accordion` height is restricted (MAW-1406).
* Placeholder in `Multiselect` was not showing up (SUI-1566).

1.5.2 - August 23, 2018
----------
Bug Fixes:
* New values in `Multiselect` were not added on click (SUI-1550).

1.5.1 - August 7, 2018
----------
Bug Fixes:
* `Resize` (in border mode) was not showing drag handles. The change introduced in 1.4.4 (for SUI-1409) was reverted.
* `react-event-listener` dependency was upgraded to avoid transitive dependency issues with `@babel/runtime` (SUI-1546).

1.5.0 - July 27, 2018
----------
New Features:
* `Concertina` panels now support a `disabled` status (SUI-529).
* `RadioList` now allows `RadioList.Option` to enable `disabled` (SUI-1534).

Bug Fixes:
* `Table` with a fixed head was calculating head column width incorrectly in some cases (SUI-1527).
* `Select` in a `ControlGroup` now works better with screen readers (SUI-1365).
* `Card` with onClick handler now renders with the same formatting as other `Card`s (SUI-1499).

1.4.4 - June 30, 2018
----------
Bug Fixes:
* Clicking away from `Multiselect` will clear filter (SUI-1263).
* Disabled `TabBar` tab will not display tooltip (SUI-1493).
* Bootstrap no longer overrides `File` input styles (SUI-1496).
* Content inside of `Resize` is not cropped (SUI-1409).

1.4.3 - June 7, 2018
----------
Bug Fixes:
* Fixed `Table` header rendering issue (SUI-1297).

Style Changes:
* `Switch` checkbox now uses a pointer cursor (SUI-1373).

1.4.2 - May 24, 2018
----------
Style Changes:
* `Button` pill hover border changed to match style guide (SUI-1390).

1.4.1 - May 3, 2018
----------
Bug Fixes:
* Fixed `MultiSelect compact` select all while disabled bug (APPLAT-835).

1.4.0 - April 23, 2018
----------
New Features:
* `Select` now supports a `suffixLabel` prop to add text after selected label (SUI-1426).
* `TabLayout.Panel` now supports a `disabled` prop (SUI-1434).

Bug Fixes:
* `Select` and `Dropdown` menu will not have overlapped rounded corners (SUI-1435).
* `Tooltip` now uses an easier to read cursor (SUI-1302).

Style Changes:
* `Table` padding changed to match style guide (SUI-1445).

1.3.3 - March 20, 2018
----------
Bug Fixes:
* `Text` now includes `name` in `onChange` callbacks after clearing (SUI-1413).

1.3.2 - March 6, 2018
----------
Bug Fixes:
* `Date` can now be set with the keyboard after pressing escape (SUI-1400).
* `Select` with a filter no longer breaks when the browser is zoomed (SUI-1378).

1.3.1 - N/A
----------
Was not published.

1.3.0 - March 2, 2018
----------
New Feature:
* `MultiSelect` now supports a `useClickawayOverlay` prop to prevent click aways from executing actions on the page (SUI-1393).

Bug Fix:
* `Select` no longer clears the filter on close (SUI-1389).

1.2.0 - February 14, 2018
----------
New Features:
* `Row` of `Table` now supports 'disabled' prop (SUI-1247).

Bug Fixes:
* Changed border-color for disabled `Text` input (SUI-1371).

1.1.1 - February 5, 2018
----------
Bug Fixes:
* Corrected brand color in `Logo` (SUI-1326).
* `StaticContent` now allows resizes vertically when text wraps (SUI-1351).
* Changed primary and error `Button` font weight to semibold (SUI-1350).
* Corrected hover color on `Button` (SUI-1364).

1.1.0 - January 25, 2018
----------
New Features:
* DOM hook added to `RenderToLayer` to facilitate interactions with Backbone components (SUI-1327).

Bug Fixes:
* Improved alignment of `Switch` with `ControlGroup` and other controls (SUI-1329).
* In `Switch`, the `value` prop is no longer required (SUI-1316).
* `RadioGroup` double borders fixed (SUI-1320).

Style Changes:
* `Slider` styles revamped (SUI-1301).
* Colors used in `Progress` updated (SUI-1317).
* Background color in `Accordion`, `Collapsible`, and `Concertina` updated to improve contrast (SUI-1324).
* Updated default and secondary button hover states to improve contrast (SUI-1325).
* Changed the color of the underline in `Tab` (SUI-1328).

1.0.0 - January 4, 2018
----------
New visual design.

New Features:
* `Heading` supports section and subsection levels (SUI-1267).
* `Button` supports secondary appearance.
* `Slider` supports an arbitrary node for `minLabel` and `maxLabel` props (SUI-1256).
* `Message` supports a `fill` prop (SUI-1305).

API Changes:
* `Heading` no longer supports level 5 (SUI-1267).

Bug Fixes:
* Accessibility improvements in `Code`.
* Resize correctly tracks to mouse position when the window or parent element is scaled (SUI-1289).
* Test hooks in `Table` head renders correct data (SUI-1268).
* `JSONTree` clickable values correctly take focus (SUI-1282).
* `Popover` and `Modal` appear at the correct `z-index` within the page stacking context (SUI-1313).
