import React from 'react';
import PropTypes from 'prop-types';
import Panel from './Panel';
import { ComponentProps } from '../utils/types';
/** @public */
type AccordionChangeHandler = (event: React.MouseEvent<HTMLButtonElement>, data: {
    event: React.MouseEvent<HTMLButtonElement>;
    panelId?: string | number;
    reason: 'toggleClick';
}) => void;
interface AccordionPropsBase {
    /**
     * Must be `Accordion.Panel`.
     */
    children?: React.ReactNode;
    /**
     * Sets the panel to expand on the initial render. Use only when using
     * `Accordion` as an uncontrolled component. Must match the `panelId` of
     * one of the `Accordion.Panel` children.
     */
    defaultOpenPanelId?: string | number;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /**
     * Inset Accordions have padding for content to the panels
     */
    inset?: boolean;
    /**
     * Invoked on a change of the open panel. Callback is passed data, such as
     * the `panelId` of the `Accordion.Panel` that originated the expand request.
     * `panelId` is `undefined` when the open panel is collapsed.
     */
    onChange?: AccordionChangeHandler;
    /**
     * Indicates the `panelId` of the currently expanded `Accordion.Panel`.
     * Use only when using `Accordion` as a controlled component.
     */
    openPanelId?: string | number;
}
interface AccordionControlledProps extends AccordionPropsBase {
    defaultOpenPanelId?: never;
    onChange: AccordionChangeHandler;
    openPanelId?: string | number;
}
interface AccordionUncontrolledProps extends AccordionPropsBase {
    defaultOpenPanelId?: string | number;
    openPanelId?: never;
}
type AccordionProps = ComponentProps<AccordionControlledProps | AccordionUncontrolledProps, 'div'>;
/**
 * @deprecated
 * Accordion has been deprecated and will be removed in a future major version. Use Collapsible Panel's SingleOpenPanelGroup API instead.
 */
declare function Accordion({ children, defaultOpenPanelId, elementRef, inset, onChange, openPanelId: openPanelIdProp, ...otherProps }: AccordionProps): React.JSX.Element;
declare namespace Accordion {
    var propTypes: {
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        defaultOpenPanelId: PropTypes.Requireable<any>;
        elementRef: PropTypes.Requireable<object>;
        inset: PropTypes.Requireable<boolean>;
        onChange: PropTypes.Requireable<(...args: any[]) => any>;
        openPanelId: PropTypes.Requireable<any>;
    };
    var Panel: typeof import("./Panel").default;
}
export default Accordion;
export { AccordionChangeHandler, Panel };
