import React from 'react';
import PropTypes from 'prop-types';
import { Enterprise, Interpolation, OptionalThemedProps, Prisma } from '@splunk/themes';
import getInitials from './getInitials';
import { ComponentProps } from '../utils/types';
/** @public */
type AvatarClickHandler = (event: React.MouseEvent<HTMLButtonElement>, data: {
    value?: string;
}) => void;
interface AvatarPropsBase {
    /**
     * All CSS color definitions are supported, such as `#223344` or `red`.
     * Using `theme` enables the theme default.
     */
    backgroundColor?: string | Interpolation<Enterprise, OptionalThemedProps<Enterprise>> | Interpolation<Prisma, OptionalThemedProps<Prisma>>;
    /** A React ref which is set to the DOM element when the component mounts and `null` when it unmounts. */
    elementRef?: React.Ref<HTMLAnchorElement | HTMLButtonElement | HTMLDivElement>;
    /** The image to be displayed inside this `Avatar`, for example an `<img>` or `<svg>`. */
    image?: React.ReactNode;
    /** The contents of this `Avatar` if the `image` prop is not set or the provided image is not valid. Must not exceed three characters in length. */
    initials: string;
    /** Text to describe what this Avatar represents. */
    label: string;
    /** Enables interactive mode. */
    onClick?: AvatarClickHandler;
    /** Adjusts the size of the `Avatar`. */
    size?: 'small' | 'medium' | 'large' | string;
    /** If set, the component will be rendered as an `<a>` tag with `href` equal to this prop rather than a `<button>` tag. */
    to?: string;
    /** @private */
    textColor?: 'auto' | string | Interpolation<Enterprise, OptionalThemedProps<Enterprise>> | Interpolation<Prisma, OptionalThemedProps<Prisma>>;
    /**
     * The value returned with `onClick` events, which can be used to identify the
     * control when multiple controls share an `onClick` callback. Not to be confused with `initials`.
     */
    value?: string;
}
type AvatarInteractiveProps = ComponentProps<AvatarPropsBase, 'button'> & {
    elementRef?: React.Ref<HTMLButtonElement | HTMLAnchorElement>;
    onClick?: AvatarClickHandler;
    to?: string;
};
type AvatarNonInteractiveProps = ComponentProps<AvatarPropsBase, 'div'> & {
    elementRef?: React.Ref<HTMLDivElement>;
    onClick?: never;
};
type AvatarProps = AvatarInteractiveProps | AvatarNonInteractiveProps;
declare function Avatar({ backgroundColor, textColor, initials, image, size, ...otherProps }: AvatarProps): React.JSX.Element;
declare namespace Avatar {
    var propTypes: {
        backgroundColor: PropTypes.Requireable<NonNullable<string | ((...args: any[]) => any) | null | undefined>>;
        elementRef: PropTypes.Requireable<object>;
        image: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        initials: PropTypes.Validator<string>;
        label: PropTypes.Validator<string>;
        onClick: PropTypes.Requireable<(...args: any[]) => any>;
        size: PropTypes.Requireable<string>;
        to: PropTypes.Requireable<string>;
        /** @private */
        textColor: PropTypes.Requireable<NonNullable<string | ((...args: any[]) => any) | null | undefined>>;
        value: PropTypes.Requireable<string>;
    };
}
export default Avatar;
export { getInitials, AvatarClickHandler };
