import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
type DayClickHandler = (event: React.MouseEvent<HTMLDivElement>, data: {
    value: string;
}) => void;
type DayKeyDownHandler = (event: React.KeyboardEvent<HTMLDivElement>, data: {
    value: string;
}) => void;
interface DayPropsBase {
    /** Whether or not this day has the active cursor. */
    active?: boolean;
    /** @private */
    dayOfWeek?: number;
    /** Locale set by language and localization specifiers. */
    locale?: string;
    /** Callback for click */
    onClick?: DayClickHandler;
    /** Callback for keyDown */
    onKeyDown?: DayKeyDownHandler;
    /** Whether or not this day is selected. */
    selected?: boolean;
    /** Indicate the day is today. */
    today?: boolean;
    /** Day number to be displayed */
    value: string;
}
type DayProps = ComponentProps<DayPropsBase, 'div'>;
declare function Day({ active, dayOfWeek, locale, onClick, onKeyDown, selected, today, value, ...otherProps }: DayProps): React.JSX.Element;
declare namespace Day {
    var propTypes: {
        active: PropTypes.Requireable<boolean>;
        /** @private. */
        dayOfWeek: PropTypes.Requireable<number>;
        locale: PropTypes.Requireable<string>;
        onClick: PropTypes.Requireable<(...args: any[]) => any>;
        onKeydown: PropTypes.Requireable<(...args: any[]) => any>;
        selected: PropTypes.Requireable<boolean>;
        today: PropTypes.Requireable<boolean>;
        value: PropTypes.Requireable<string>;
    };
}
export default Day;
export { DayClickHandler, DayKeyDownHandler };
