import React from 'react';
import PropTypes from 'prop-types';
import { defaultPalette } from './Palette';
import { ComponentProps } from '../utils/types';
/** @public */
type ColorChangeHandler = (data: {
    name?: string;
    value?: string | null;
}) => void;
interface ColorPropsBase {
    /** Append removes border from the right side. */
    append?: boolean;
    /** Set this property instead of value to make value uncontrolled. */
    defaultValue?: string | null;
    /**
     * The id of the description. When placed in a ControlGroup, this is automatically set to the
     * ControlGroup's help component.
     */
    describedBy?: string;
    /** Add a disabled attribute and prevent clicking. */
    disabled?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /** Add an error attribute. */
    error?: boolean;
    /**
     * Set this property to hide the hex value text input in the initial appearance.
     * The input will still appear inside the dropdown when opened.
     */
    hideInput?: boolean;
    /**
     * The id of the label. When placed in a ControlGroup, this is automatically set to the
     * ControlGroup's label.
     */
    labelledBy?: string;
    /** The name is returned with onChange events, which can be used to identify the
     * control when multiple controls share an onChange callback. */
    name?: string;
    /** A callback that receives the value of a newly selected color. */
    onChange?: ColorChangeHandler;
    /** An array of optional color swatch values (hexadecimal or 'transparent').
     * The 'transparent' option should only be put at the start or end of the palette. */
    palette?: (string | null)[];
    /** This has no effect on the appearance at this time but is recommended to be used when a
     * control is joined to the left. Styles may change in the future. */
    prepend?: boolean;
    /** @private */
    required?: boolean;
    /**
     * The value of the color (hexadecimal or 'transparent').
     * Setting this value makes the property controlled.
     * An `onChange` callback is required.
     */
    value?: string | null;
}
interface ColorPropsBaseControlled extends ColorPropsBase {
    defaultValue?: never;
    onChange: ColorChangeHandler;
    value?: string | null;
}
interface ColorPropsBaseUncontrolled extends ColorPropsBase {
    defaultValue?: string | null;
    value?: never;
}
type ColorProps = ComponentProps<ColorPropsBaseControlled | ColorPropsBaseUncontrolled, 'div'>;
declare function Color({ append, defaultValue, disabled, describedBy, elementRef, error, hideInput, labelledBy, name, onChange, palette, prepend, required, value: valueProp, ...otherProps }: ColorProps): React.JSX.Element;
declare namespace Color {
    var propTypes: {
        append: PropTypes.Requireable<boolean>;
        defaultValue: PropTypes.Requireable<string>;
        describedBy: PropTypes.Requireable<string>;
        disabled: PropTypes.Requireable<boolean>;
        elementRef: PropTypes.Requireable<object>;
        error: PropTypes.Requireable<boolean>;
        hideInput: PropTypes.Requireable<boolean>;
        labelledBy: PropTypes.Requireable<string>;
        name: PropTypes.Requireable<string>;
        onChange: PropTypes.Requireable<(...args: any[]) => any>;
        palette: PropTypes.Requireable<any[]>;
        prepend: PropTypes.Requireable<boolean>;
        /** @private */
        required: PropTypes.Requireable<boolean>;
        value: PropTypes.Requireable<string>;
    };
    var componentType: string;
}
export default Color;
export { defaultPalette };
export type { ColorChangeHandler, ColorPropsBase, ColorPropsBaseControlled, ColorPropsBaseUncontrolled, };
