import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
/** @public */
type DateChangeHandler = (event: React.MouseEvent<HTMLButtonElement | HTMLDivElement> | React.KeyboardEvent<HTMLInputElement> | React.KeyboardEvent<HTMLDivElement> | KeyboardEvent | MouseEvent | TouchEvent | undefined, data: {
    name?: string;
    value: string;
}) => void;
/** @public */
type DateBlurHandler = (event: React.FocusEvent<HTMLInputElement>, data: {
    name?: string;
    value: string;
}) => void;
/** @public */
type DateFocusHandler = (event: React.FocusEvent<HTMLInputElement>, data: {
    name?: string;
    value: string;
}) => void;
interface DatePropsBase {
    /** Default date to display. Set this instead of value to make the Date uncontrolled. */
    defaultValue?: string;
    /**
     * The id of the description. When placed in a ControlGroup, this automatically set to the
     * ControlGroup's help component.
     */
    describedBy?: string;
    /** Add a disabled attribute and prevent clicking. */
    disabled?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /**
     * Highlight the field as having an error. The border and text will turn red.
     */
    error?: boolean;
    /** Highlight today's day. */
    highlightToday?: boolean;
    /** When false, display as inline-block with the default width. */
    inline?: boolean;
    /**
     * The id of the label. When placed in a ControlGroup, this automatically set to the
     * ControlGroup's label.
     */
    labelledBy?: string;
    /**
     * An id for the input, which may be necessary for accessibility, such as for aria
     * attributes.
     */
    inputId?: string;
    /**
     * Whether or not to display the calendar menu.
     */
    inputOnly?: boolean;
    /** Locale set by language and localization specifiers. */
    locale?: string;
    /** The name is returned with onChange events, which can be used to identify the
     * control when multiple controls share an onChange callback. */
    name?: string;
    /** A callback for when the input loses focus. */
    onBlur?: DateBlurHandler;
    /**
     * Return event and data object with date string (in YYYY-MM-DD format) when a date is
     * selected.
     */
    onChange?: DateChangeHandler;
    onClick?: React.MouseEventHandler<HTMLInputElement>;
    onFocus?: DateFocusHandler;
    onKeyDown?: React.KeyboardEventHandler<HTMLInputElement>;
    /**
     * Setting this value makes the property controlled. An onChange callback is required.
     *
     * The value must be "" or in the format 'YYYY-MM-DD'. To simplify creation of these strings,
     * Date provides a Moment.js formatting string:
     * ```
     * moment().format(Date.momentFormat);
     * ```
     */
    value?: string;
}
interface DatePropsBaseControlled extends DatePropsBase {
    defaultValue?: never;
    onChange: DateChangeHandler;
    value?: string;
}
interface DatePropsBaseUncontrolled extends DatePropsBase {
    defaultValue?: string;
    value?: never;
}
type DateProps = ComponentProps<DatePropsBaseControlled | DatePropsBaseUncontrolled, 'div'>;
declare const validateValue: (value: string | undefined) => void;
declare function Date({ defaultValue, disabled, elementRef, highlightToday, inline, inputOnly, locale, name, onChange, onClick, onFocus, onKeyDown, value: valueProp, ...otherProps }: DateProps): React.JSX.Element;
declare namespace Date {
    var propTypes: {
        defaultValue: PropTypes.Requireable<string>;
        describedBy: PropTypes.Requireable<string>;
        disabled: PropTypes.Requireable<boolean>;
        elementRef: PropTypes.Requireable<object>;
        error: PropTypes.Requireable<boolean>;
        highlightToday: PropTypes.Requireable<boolean>;
        inline: PropTypes.Requireable<boolean>;
        inputId: PropTypes.Requireable<string>;
        inputOnly: PropTypes.Requireable<boolean>;
        labelledBy: PropTypes.Requireable<string>;
        locale: PropTypes.Requireable<string>;
        name: PropTypes.Requireable<string>;
        onBlur: PropTypes.Requireable<(...args: any[]) => any>;
        onChange: PropTypes.Requireable<(...args: any[]) => any>;
        onClick: PropTypes.Requireable<(...args: any[]) => any>;
        onFocus: PropTypes.Requireable<(...args: any[]) => any>;
        onKeyDown: PropTypes.Requireable<(...args: any[]) => any>;
        value: PropTypes.Requireable<string>;
    };
    var momentFormat: string;
}
export default Date;
export { DateBlurHandler, DateChangeHandler, DateFocusHandler, validateValue };
export type { DatePropsBase, DatePropsBaseControlled, DatePropsBaseUncontrolled };
