import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
interface DividerPropsBase {
    /**
     * Changes the border color of the `Divider`.
     * `Divider`s with `appearance="weak"` will not meet accessibility requirements to be perceivable.
     * If the component should be perceivable, consider the other contrast compliant `appearance` values.
     * Otherwise, apply the `decorative` prop.
     */
    appearance?: 'default' | 'weak' | 'strong';
    /**
     * Remove semantics of the divider.
     */
    decorative?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLHRElement>;
    /** Sets the orientation of this `Divider`. */
    orientation?: 'horizontal' | 'vertical';
}
type DividerProps = ComponentProps<DividerPropsBase, 'hr' | 'div'>;
declare function Divider({ appearance, elementRef, decorative, orientation, ...otherProps }: DividerProps): React.JSX.Element;
declare namespace Divider {
    var propTypes: {
        appearance: PropTypes.Requireable<string>;
        decorative: PropTypes.Requireable<boolean>;
        elementRef: PropTypes.Requireable<object>;
        orientation: PropTypes.Requireable<string>;
    };
}
export default Divider;
