import React from 'react';
import PropTypes from 'prop-types';
import Row from './Row';
import type { RowRequestRemoveHandler } from './Row';
import { ComponentProps } from '../utils/types';
/** @public */
type FormRowsRequestMoveHandler = (data: {
    fromIndex: number;
    toIndex: number;
}) => void;
interface FormRowsPropsBase {
    /** Label on the Add row button. Ignored when menu prop is defined. */
    addLabel?: string;
    /** @private */
    children?: React.ReactNode;
    /** Disable the Add row button, the Remove button and the sort/drag action. */
    disabled?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts, and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /** Header for the rows. */
    header?: React.ReactNode;
    /** Replaces Add row button with custom content or controls. */
    menu?: React.ReactNode;
    /** Callback when the Add row button is clicked. If `onRequestAdd` is defined, 'onRequestRemove' should be defined in `<FormRows.Row>`. Neither should be defined for a reorder-only variant of `<FormRows>`. */
    onRequestAdd?: React.MouseEventHandler<HTMLButtonElement | HTMLAnchorElement>;
    /** Callback when sort action completes. Omit this to make rows unsortable. */
    onRequestMove?: FormRowsRequestMoveHandler;
}
type FormRowsProps = ComponentProps<FormRowsPropsBase, 'div'>;
declare function FormRows({ addLabel, children, disabled, elementRef, header, menu, onRequestAdd, onRequestMove, ...otherProps }: FormRowsProps): React.JSX.Element;
declare namespace FormRows {
    var propTypes: {
        addLabel: PropTypes.Requireable<string>;
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        disabled: PropTypes.Requireable<boolean>;
        elementRef: PropTypes.Requireable<object>;
        header: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        menu: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        onRequestAdd: PropTypes.Requireable<(...args: any[]) => any>;
        onRequestMove: PropTypes.Requireable<(...args: any[]) => any>;
    };
    var Row: typeof import("./Row").default;
    var addRow: (element: React.ReactElement, items: React.ReactElement[]) => React.ReactElement<any, string | React.JSXElementConstructor<any>>[];
    var moveRow: (fromIndex: number, toIndex: number, items: React.ReactElement[]) => React.ReactElement<any, string | React.JSXElementConstructor<any>>[];
    var removeRow: (index: number, items: React.ReactElement[]) => React.ReactElement<any, string | React.JSXElementConstructor<any>>[];
}
export default FormRows;
export { Row };
export type { FormRowsRequestMoveHandler, RowRequestRemoveHandler };
