import React from 'react';
import { ComponentProps } from '../utils/types';
interface LinkPropsBase {
    /**
     * Changes the style of the link.
     */
    appearance?: 'inline' | 'standalone';
    children?: React.ReactNode;
    /**
     * Adds an aria-disabled attribute and prevents clicking.
     */
    disabled?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLButtonElement | HTMLAnchorElement>;
    /**
     * Open the "to" link in a new context, which is usually a new tab or window based on browser settings.
     *
     * An icon and a screen reader message is added to indicate this behavior to users.
     * The default message is "(Opens new window)"; this can be customized by passing
     * a string instead of boolean to `openInNewContext`.
     */
    openInNewContext?: boolean | string;
    /**
     * The onClick event handler is ignored if Ctrl or meta keys are pressed,
     * which allows the link to open in a new context.
     */
    onClick?: React.MouseEventHandler<HTMLButtonElement | HTMLAnchorElement>;
    /**
     * The URL or path to link to.
     */
    to?: string;
    /**
     * @private
     */
    tag?: 'a' | 'button';
}
type LinkLinkProps = ComponentProps<LinkPropsBase, 'a', 'href'>;
type LinkButtonProps = ComponentProps<LinkPropsBase, 'button'>;
type LinkProps = LinkLinkProps | LinkButtonProps;
/**
 * `Link` is a simple method for configuring `Button` for inline links. For more complex behaviors,
 * see the `Button` documentation.
 */
declare const Link: React.ForwardRefExoticComponent<LinkProps & React.RefAttributes<HTMLAnchorElement | HTMLButtonElement>>;
export default Link;
export { LinkProps };
