import React from 'react';
import PropTypes from 'prop-types';
import Item from './Item';
import { Styled } from './ListStyles';
import { ComponentProps } from '../utils/types';
interface ListPropsBase {
    children?: React.ReactNode;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     *
     * `HTMLUListElement` if type is 'disc', `HTMLOListElement` otherwise.
     */
    elementRef?: React.Ref<HTMLOListElement | HTMLUListElement>;
    /** Sets the element as an `HTMLOListElement`  otherwise it defaults to `HTMLUListElement`. */
    ordered?: boolean;
}
interface ListOrderedPropsBase extends ListPropsBase {
    elementRef?: React.Ref<HTMLOListElement>;
    ordered: true;
}
interface ListUnorderedPropsBase extends ListPropsBase {
    elementRef?: React.Ref<HTMLUListElement>;
}
type ListUnorderedProps = ComponentProps<ListUnorderedPropsBase, 'ul'>;
type ListOrderedProps = ComponentProps<ListOrderedPropsBase, 'ol'>;
type ListProps = ListUnorderedProps | ListOrderedProps;
declare function List({ children, elementRef, ordered, ...otherProps }: ListProps): React.JSX.Element;
declare namespace List {
    var propTypes: {
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        elementRef: PropTypes.Requireable<object>;
        ordered: PropTypes.Requireable<boolean>;
    };
    var Item: typeof import("./Item").default;
}
export default List;
export { Item, Styled as StyledList };
