import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
interface HeaderPropsBase {
    /**
     * `children` might be passed instead of a title. Note that `children` aren't
     * rendered if a title is provided.
     */
    children?: React.ReactNode;
    /**
     * Hide the closeButton in the Header if `onRequestClose` is provided to `Modal`.
     */
    hideCloseButton?: boolean;
    /**
     * The icon to show before the title.
     */
    icon?: React.ReactNode;
    /**
     * Used as the main heading.
     */
    title?: string;
    /**
     * Used as the subheading. Only shown if `title` is also present.
     */
    subtitle?: React.ReactNode;
}
type HeaderProps = ComponentProps<HeaderPropsBase, 'div'>;
/**
 * A styled container for `Modal` header content.
 */
declare function Header({ children, icon, hideCloseButton, title, subtitle, ...otherProps }: HeaderProps): React.JSX.Element;
declare namespace Header {
    var propTypes: {
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        icon: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        hideCloseButton: PropTypes.Requireable<boolean>;
        title: PropTypes.Requireable<string>;
        subtitle: PropTypes.Requireable<PropTypes.ReactNodeLike>;
    };
}
export default Header;
