import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
interface ProgressPropsBase {
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /**
     * The percentage complete. If unset, no progress bar is shown.
     * Percentage must be a number from 0-100.
     */
    percentage?: number;
    /** Tooltip defaults to the percentage complete. */
    tooltip?: React.ReactNode;
    /**
     * Sets the appearance of the `Progress` component.
     *
     * Note: `success` and `error` types are not animated.
     */
    type?: 'info' | 'success' | 'error';
}
type ProgressProps = ComponentProps<ProgressPropsBase, 'div'>;
declare function Progress({ elementRef, percentage, tooltip, type, ...otherProps }: ProgressProps): React.JSX.Element;
declare namespace Progress {
    var propTypes: {
        elementRef: PropTypes.Requireable<object>;
        percentage: PropTypes.Requireable<number>;
        tooltip: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        type: PropTypes.Requireable<string>;
    };
}
export default Progress;
