import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
type OptionClickHandler = (event: React.MouseEvent<HTMLAnchorElement | HTMLButtonElement> | React.KeyboardEvent<HTMLElement>, data: {
    label?: string;
    value: any;
}) => void;
type OnKeyDownHandler = (event: React.KeyboardEvent<HTMLElement>, data: {
    label?: string;
    value: any;
}) => void;
type OnChangeHandler = (event: React.KeyboardEvent<HTMLElement> | React.MouseEvent<HTMLAnchorElement | HTMLButtonElement>, data: {
    label?: string;
    value: any;
}) => void;
interface OptionPropsBase {
    /** Add a disabled attribute and prevent clicking. */
    disabled?: boolean;
    /** Adornment after the label. */
    endAdornment?: React.ReactNode;
    /** The text shown on the button. */
    label?: string;
    role?: 'radio' | 'menuitemradio';
    /** Adornment in front of the label. */
    startAdornment?: React.ReactNode;
    /** @private Set by `RadioBar`. */
    selected?: boolean;
    /** The value of the `Option`. */
    value: any;
}
type OptionProps = ComponentProps<OptionPropsBase, 'button'>;
declare function Option({ disabled, label, selected, startAdornment, endAdornment, value, role, ...otherProps }: OptionProps): React.JSX.Element;
declare namespace Option {
    var propTypes: {
        disabled: PropTypes.Requireable<boolean>;
        startAdornment: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        endAdornment: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        label: PropTypes.Requireable<string>;
        /** @private Set by `RadioBar`. */
        role: PropTypes.Requireable<string>;
        /** @private Set by `RadioBar`. */
        selected: PropTypes.Requireable<boolean>;
        /** The value of the `Option`. */
        value: PropTypes.Validator<any>;
    };
}
export default Option;
export { OptionClickHandler, OnKeyDownHandler, OnChangeHandler };
