import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
import Option from './Option';
type RadioListValueTypes = number | string | boolean | Record<string, unknown> | symbol;
/** @public */
type RadioListChangeHandler = (event: React.ChangeEvent<HTMLInputElement>, data: {
    name?: string;
    value: RadioListValueTypes;
}) => void;
interface RadioListPropsBase {
    /**
     * `children` should be `RadioList.Option`s.
     */
    children?: React.ReactNode;
    /**
     * Set this property instead of value to make value uncontrolled.
     */
    defaultValue?: RadioListValueTypes;
    /**
     * When placed in a ControlGroup, this is automatically set to the ControlGroup's help component.
     * @private
     */
    describedBy?: string;
    /**
     * Changes the layout of the RadioList.
     * @deprecated This prop is deprecated and will be removed in the next major version.
     */
    direction?: 'column' | 'row';
    disabled?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /**
     * Highlight the field as having an error. The buttons and labels will turn red.
     */
    error?: boolean;
    /**
     * When placed in a ControlGroup, this is automatically set to the ControlGroup's label.
     * @private
     */
    labelledBy?: string;
    /** The name is returned with onChange events, which can be used to identify the
     * control when multiple controls share an onChange callback.
     * A randomly generated name is used if one is not provided. */
    name?: string;
    /**
     * A callback to receive the change events.
     * If value is set, this callback is required. This must set the value prop to retain the
     * change.
     */
    onChange?: RadioListChangeHandler;
    /** @private. */
    required?: boolean;
    /** The current selected value.  Setting this value makes the property controlled. A
     * callback is required.
     */
    value?: RadioListValueTypes;
}
interface RadioListPropsBaseControlled extends RadioListPropsBase {
    value: RadioListValueTypes;
    onChange: RadioListChangeHandler;
    defaultValue?: never;
}
interface RadioListPropsBaseUncontrolled extends RadioListPropsBase {
    onChange?: RadioListChangeHandler;
    defaultValue?: RadioListValueTypes;
    value?: never;
}
type RadioListProps = ComponentProps<RadioListPropsBaseControlled | RadioListPropsBaseUncontrolled, 'div'>;
declare function RadioList({ children, defaultValue: defaultValueProp, describedBy, direction, disabled, elementRef, error, labelledBy, name: nameProp, onChange, required, value: valueProp, ...otherProps }: RadioListProps): React.JSX.Element;
declare namespace RadioList {
    var propTypes: {
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        defaultValue: PropTypes.Requireable<any>;
        describedBy: PropTypes.Requireable<string>;
        direction: PropTypes.Requireable<string>;
        disabled: PropTypes.Requireable<boolean>;
        elementRef: PropTypes.Requireable<object>;
        error: PropTypes.Requireable<boolean>;
        labelledBy: PropTypes.Requireable<string>;
        name: PropTypes.Requireable<string>;
        onChange: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. */
        required: PropTypes.Requireable<boolean>;
        value: PropTypes.Requireable<any>;
    };
    var Option: typeof import("./Option").default;
}
export default RadioList;
export { Option, RadioListValueTypes, RadioListChangeHandler };
export type { RadioListPropsBase, RadioListPropsBaseControlled, RadioListPropsBaseUncontrolled };
