import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
/** @public */
type ResizeDirection = 'nw' | 'n' | 'ne' | 'w' | 'e' | 'sw' | 's' | 'se';
/** @public */
type ResizeRequestResizeHandler = (event: MouseEvent | React.KeyboardEvent<HTMLButtonElement>, data: {
    height: number;
    width: number;
}) => void;
interface ResizePropsBase {
    /** The appearance of the resize handles.
     * Note: When appearance is 'separator', active full length borders will only appear for 'n', 's', 'e', or 'w' `resizeHandles`.
     */
    appearance?: 'border' | 'overlay' | 'separator';
    /** The appearance of the resize handles. */
    showHandles?: 'always' | 'on-hover';
    children?: React.ReactNode;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /** When focused on a resize handle, the arrow keys will adjust the height or width by
     * this amount with each press. */
    keyIncrement?: number;
    /** A callback which is passed the event and an object with the requested height and width. */
    onRequestResize: ResizeRequestResizeHandler;
    /** An array of resize handles placements. */
    resizeHandles: ResizeDirection[];
}
type ResizeProps = ComponentProps<ResizePropsBase, 'div'>;
/**
 * Resize is a utility container with drag handles for resizing.
 */
declare function Resize({ appearance, children, elementRef, keyIncrement, onRequestResize, resizeHandles, showHandles, ...otherProps }: ResizeProps): React.JSX.Element;
declare namespace Resize {
    var propTypes: {
        appearance: PropTypes.Requireable<string>;
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        elementRef: PropTypes.Requireable<object>;
        keyIncrement: PropTypes.Requireable<number>;
        onRequestResize: PropTypes.Validator<(...args: any[]) => any>;
        resizeHandles: PropTypes.Validator<(string | null | undefined)[]>;
        showHandles: PropTypes.Requireable<string>;
    };
}
export default Resize;
export { ResizeDirection, ResizeRequestResizeHandler };
