import React from 'react';
import PropTypes from 'prop-types';
import { TransitionOpenPropsBase } from '@splunk/react-ui/TransitionOpen';
import { ComponentProps } from '../utils/types';
/** @public */
type SidePanelRequestCloseHandler = (data: {
    event: React.MouseEvent<HTMLDivElement> | MouseEvent | KeyboardEvent | TouchEvent;
    reason: 'clickAway' | 'escapeKey';
}) => void;
interface SidePanelPropsBase extends TransitionOpenPropsBase {
    children?: React.ReactNode;
    /**
     * The position of the Panel on the screen.
     */
    dockPosition?: 'top' | 'bottom' | 'left' | 'right';
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /**
     * The inner element can control the width of the side bar when placed left or right and
     * the height when placed top or bottom.
     */
    innerClassName?: string;
    /**
     * The inner element can control the width of the side bar when placed left or right and
     * the height when placed top or bottom.
     */
    innerStyle?: React.CSSProperties;
    /**
     * A function called when the open / close animation ends.
     */
    onAnimationEnd?: () => void;
    /**
     * A function that is called when a close event occurs. The callback is passed a
     * reason and the event.
     *
     * Generally, this callback should be used to toggle the `open` prop.
     */
    onRequestClose?: SidePanelRequestCloseHandler;
    /**
     * Indicates the current open state of the panel.
     */
    open?: boolean;
    /**
     * The outer element grows to the width of the side bar when placed left or right or
     * the height when placed top or bottom. It has minimal styles:
     * a white background and a box shadow. Adding styles to this container
     * can be useful when the sidebar must be shorter than the width or height of the page
     * or when multiple sidebars are shown.
     */
    outerClassName?: string;
    /**
     * The outer element grows to the width of the side bar when placed left or right or
     * the height when placed top or bottom. It has minimal styles:
     * a white background and a box shadow. Adding styles to this container
     * can be useful when the sidebar must be shorter than the width or height of the page
     * or when multiple sidebars are shown.
     */
    outerStyle?: React.CSSProperties;
    /**
     * Indicates whether to add an overlay mask on the whole page, blocking other interactions
     * while the Panel is open.
     */
    useLayerForClickAway?: boolean;
}
type SidePanelProps = ComponentProps<SidePanelPropsBase, 'div'>;
declare function SidePanel({ children, dockPosition, elementRef, innerClassName, innerStyle, onAnimationEnd, onRequestClose, open, outerClassName, outerStyle, useLayerForClickAway, ...otherProps }: SidePanelProps): React.JSX.Element;
declare namespace SidePanel {
    var propTypes: {
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        dockPosition: PropTypes.Requireable<string>;
        elementRef: PropTypes.Requireable<object>;
        innerClassName: PropTypes.Requireable<string>;
        innerStyle: PropTypes.Requireable<object>;
        onAnimationEnd: PropTypes.Requireable<(...args: any[]) => any>;
        onRequestClose: PropTypes.Requireable<(...args: any[]) => any>;
        open: PropTypes.Requireable<boolean>;
        outerClassName: PropTypes.Requireable<string>;
        outerStyle: PropTypes.Requireable<object>;
        useLayerForClickAway: PropTypes.Requireable<boolean>;
    };
}
export default SidePanel;
export { SidePanelRequestCloseHandler };
