import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
interface PanelPropsBase {
    children?: React.ReactNode;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /**
     * Used internally, func passed in from outer place is overwritten
     * by SlidingPanels during rendering
     * @private
     */
    onMount?: (panel: HTMLDivElement | null, panelId: any) => void;
    /**
     * Used internally, func passed in from outer place is overwritten
     * by SlidingPanels during rendering
     * @private
     */
    onUnmount?: (panelId: any) => void;
    /**
     * A unique `id` for this panel and used by the SlidingPanels to keep track of the open panel.
     */
    panelId: string | number;
}
type PanelProps = ComponentProps<PanelPropsBase, 'div'>;
/**
 * Container for arbitrary content.
 */
declare function Panel({ children, elementRef, onMount, onUnmount, panelId, ...otherProps }: PanelProps): React.JSX.Element;
declare namespace Panel {
    var propTypes: {
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        elementRef: PropTypes.Requireable<object>;
        /** @private */
        onMount: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private */
        onUnmount: PropTypes.Requireable<(...args: any[]) => any>;
        panelId: PropTypes.Validator<NonNullable<NonNullable<string | number | null | undefined>>>;
    };
}
export default Panel;
export { PanelPropsBase };
