import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
/** @public */
type SwitchClickHandler = (event: React.MouseEvent<HTMLButtonElement>, data: {
    selected: boolean;
    value?: any;
}) => void;
/** @public */
type SwitchCheckboxWithSomeClickHandler = (event: React.MouseEvent<HTMLButtonElement>, data: {
    selected: boolean | 'some';
    value?: any;
}) => void;
interface SwitchPropsBase {
    appearance?: 'checkbox' | 'toggle';
    children?: React.ReactNode;
    disabled?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts, and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /**
     * Highlight the field as having an error only when appearance is 'checkbox'.
     */
    error?: boolean;
    /**
     * If `Switch` is not provided children as the label, an id can be provided for the control.
     * Set a label's for attribute to this id to link the two elements.
     */
    id?: string;
    /**
     * Make the control an inline block with variable width.
     */
    inline?: boolean;
    /**
     * If `Switch` is not provided children as the label, an id can be provided to
     * another element.
     */
    labelledBy?: string;
    onClick?: SwitchClickHandler | SwitchCheckboxWithSomeClickHandler;
    /** @private. */
    required?: boolean;
    /**
     * 'some' is only valid when appearance is 'checkbox'. The current value of `selected` is
     * passed to the onClick handler.
     */
    selected?: boolean | 'some';
    /**
     * The customized content presented to screen readers when selected.
     */
    selectedLabel?: string;
    /**
     * The customized content presented to screen readers when selected="some".
     */
    someSelectedLabel?: string;
    /**
     * A React ref which is set to the toggle when the component mounts and null when it unmounts.
     */
    toggleRef?: React.Ref<HTMLAnchorElement | HTMLButtonElement | HTMLSpanElement>;
    /**
     * The customized content presented to screen readers when unselected.
     */
    unselectedLabel?: string;
    /**
     * The `value` is used as an identifier and is passed to the `onClick` handler. This is
     * useful when managing a group of switches with a single `onClick` handler.
     */
    value?: any;
}
interface SwitchCheckboxWithSomePropsBase extends SwitchPropsBase {
    appearance?: 'checkbox';
    onClick?: SwitchCheckboxWithSomeClickHandler;
    selected?: boolean | 'some';
    error?: boolean;
}
interface SwitchNoSomePropsBase extends SwitchPropsBase {
    onClick?: SwitchClickHandler;
    selected?: boolean;
    error?: never;
}
type SwitchProps = ComponentProps<SwitchCheckboxWithSomePropsBase | SwitchNoSomePropsBase, 'div'>;
/**
 * `Switch` is a basic form control with an on/off state.
 */
declare function Switch({ appearance, children, disabled, elementRef, error, id, inline, labelledBy, onClick, required, selected, selectedLabel, someSelectedLabel, toggleRef, unselectedLabel, value, ...otherProps }: SwitchProps): React.JSX.Element;
declare namespace Switch {
    var propTypes: {
        appearance: PropTypes.Requireable<string>;
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        disabled: PropTypes.Requireable<boolean>;
        elementRef: PropTypes.Requireable<object>;
        error: PropTypes.Requireable<boolean>;
        id: PropTypes.Requireable<string>;
        inline: PropTypes.Requireable<boolean>;
        labelledBy: PropTypes.Requireable<string>;
        onClick: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. */
        required: PropTypes.Requireable<boolean>;
        selected: PropTypes.Requireable<string | boolean>;
        selectedLabel: PropTypes.Requireable<string>;
        toggleRef: PropTypes.Requireable<object>;
        someSelectedLabel: PropTypes.Requireable<string>;
        unselectedLabel: PropTypes.Requireable<string>;
        value: PropTypes.Requireable<any>;
    };
}
export default Switch;
export { SwitchClickHandler, SwitchCheckboxWithSomeClickHandler };
