import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
type TabClickHandler = (event: React.MouseEvent<HTMLButtonElement>, data: {
    tabId: string;
}) => void;
type TabFocusHandler = (event: React.FocusEvent<HTMLButtonElement>, data: {
    tabId: string;
}) => void;
interface TabPropsBase {
    /**
     * The ariaControls prop is the element `id` of the content displayed when the tab is selected.
     */
    ariaControls?: string;
    /** Inserts number in tab label. */
    count?: number;
    /** Prevents user from clicking the tab. */
    disabled?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLButtonElement | HTMLAnchorElement>;
    /** See Icon documentation for more information. */
    icon?: React.ReactNode;
    /**
     * Placed on the clickable element. For accessibility, the related content must
     * have an `aria-labelledby` attribute that matches this `id`. The `id` must be unique
     * within the document, unlike `tabId`, which must be unique within the `TabBar` instance.
     */
    id?: string;
    /** The text shown in the button. */
    label?: React.ReactNode;
    /** @private Maximum count number in tab label */
    maxCount?: number;
    /**
     * A unique `id` for this tab and used by the `TabBar` to keep track of the open tab.
     * If not provided, one will be automatically generated for the tab.
     */
    tabId?: string;
    /** Identifies the URL for a link. If set, Splunk UI applies an <a> tag
     * instead of a <button> tag. */
    to?: string;
    /**
     * Content to show in a tooltip.
     */
    tooltip?: React.ReactNode;
    /**
     * @private
     * Accepts a Menu component that is rendered for that Tab.
     * Is not compatible with `count`.
     * The `menu` prop is only supported in horizontal layout due to both design constraints as well as keyboard support.
     */
    menu?: React.ReactNode;
    /**
     * @private
     * Internal prop injected by TabBar to track focus order.
     */
    index?: number;
}
type TabProps = ComponentProps<TabPropsBase, 'div'>;
declare const Tab: {
    ({ ariaControls, count, disabled, elementRef, icon, label, maxCount, tabId: tabIdProp, to, tooltip, menu, index, ...otherProps }: TabProps): React.JSX.Element;
    propTypes: {
        ariaControls: PropTypes.Requireable<string>;
        count: PropTypes.Requireable<number>;
        disabled: PropTypes.Requireable<boolean>;
        elementRef: PropTypes.Requireable<object>;
        icon: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        id: PropTypes.Requireable<string>;
        label: PropTypes.Requireable<NonNullable<string | PropTypes.ReactElementLike | null | undefined>>;
        /** @private Maximum count number in tab label */
        maxCount: PropTypes.Requireable<number>;
        tabId: PropTypes.Requireable<string>;
        to: PropTypes.Requireable<string>;
        tooltip: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /**
         * @private
         * Accepts a Menu component that is rendered for that Tab.
         * Is not compatible with `count`.
         * The `menu` prop is only supported in horizontal layout due to both design constraints as well as keyboard support.
         */
        menu: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /**
         * @private
         * Internal prop injected by TabBar to track order.
         */
        index: PropTypes.Requireable<number>;
    };
    as: string;
};
export default Tab;
export { TabClickHandler, TabFocusHandler };
export type { TabPropsBase };
