import React from 'react';
import PropTypes from 'prop-types';
import Tab from './Tab';
import { ComponentProps } from '../utils/types';
/** @public */
type TabBarChangeHandler = (event: React.MouseEvent<HTMLButtonElement> | React.FocusEvent<HTMLButtonElement>, data: {
    selectedTabId?: string;
}) => void;
interface TabBarPropsBase {
    /** If `true`, tabs will trigger the `onChange` callback when they receive focus.  */
    autoActivate?: boolean;
    /** The `tabId` of the `TabBar.Tab` to activate. */
    activeTabId?: string;
    /**
     * Must be `TabBar.Tab`.
     */
    children?: React.ReactNode;
    /** @private */
    disabled?: boolean;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /**
     * Position of icon in `TabBar.Tab` if it has an icon. Defaults to "left".
     * @deprecated This prop is deprecated and will be removed in the next major version.
     */
    iconPosition?: 'above' | 'left';
    /** The layout of tabs. */
    layout?: 'horizontal' | 'vertical';
    /** Max width of each `TabBar.Tab` in pixels. Leave blank for auto max width. */
    maxTabWidth?: number;
    /** A callback that receives the event and data (`selectedTabId`). */
    onChange?: TabBarChangeHandler;
}
type TabBarProps = ComponentProps<TabBarPropsBase, 'div'>;
declare function TabBar({ activeTabId, autoActivate, children, disabled, elementRef, iconPosition, layout, maxTabWidth, onChange, ...otherProps }: TabBarProps): React.JSX.Element;
declare namespace TabBar {
    var propTypes: {
        autoActivate: PropTypes.Requireable<boolean>;
        activeTabId: PropTypes.Requireable<string>;
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /** @private */
        disabled: PropTypes.Requireable<boolean>;
        elementRef: PropTypes.Requireable<object>;
        iconPosition: PropTypes.Requireable<string>;
        layout: PropTypes.Requireable<string>;
        maxTabWidth: PropTypes.Requireable<number>;
        onChange: PropTypes.Requireable<(...args: any[]) => any>;
    };
    var Tab: {
        ({ ariaControls, count, disabled, elementRef, icon, label, maxCount, tabId: tabIdProp, to, tooltip, menu, index, ...otherProps }: import("./Tab").TabPropsBase & Omit<React.DetailedHTMLProps<React.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, "ref" | "css" | keyof import("./Tab").TabPropsBase>): React.JSX.Element;
        propTypes: {
            ariaControls: PropTypes.Requireable<string>;
            count: PropTypes.Requireable<number>;
            disabled: PropTypes.Requireable<boolean>;
            elementRef: PropTypes.Requireable<object>;
            icon: PropTypes.Requireable<PropTypes.ReactNodeLike>;
            id: PropTypes.Requireable<string>;
            label: PropTypes.Requireable<NonNullable<string | PropTypes.ReactElementLike | null | undefined>>;
            maxCount: PropTypes.Requireable<number>;
            tabId: PropTypes.Requireable<string>;
            to: PropTypes.Requireable<string>;
            tooltip: PropTypes.Requireable<PropTypes.ReactNodeLike>;
            menu: PropTypes.Requireable<PropTypes.ReactNodeLike>;
            index: PropTypes.Requireable<number>;
        };
        as: string;
    };
}
export default TabBar;
export { Tab };
export type { TabBarChangeHandler, TabBarPropsBase };
