import React from 'react';
import PropTypes from 'prop-types';
import { TableRequestMoveColumnHandler } from './Table';
import { ComponentProps } from '../utils/types';
type HeadAutosizeColumnHandler = (event: React.MouseEvent<HTMLHRElement>, data: {
    columnId?: string;
    index: number;
}) => void;
type HeadRequestMoveColumnHandler = TableRequestMoveColumnHandler;
type HeadRequestResizeColumnHandler = (event: React.KeyboardEvent<HTMLHRElement> | MouseEvent, data: {
    columnId?: string;
    id?: string;
    index: number;
    width: number;
}) => void;
interface HeadPropsBase {
    /** @private. */
    actions?: React.ReactNode[];
    /** @private. */
    actionsColumnWidth?: number;
    /** @private. The minimum width of each column */
    cellMinWidth?: number;
    /**
     * Must be `Table.HeadCell`s or `Table.HeadDropdownCell`s.
     */
    children?: React.ReactNode;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLTableSectionElement>;
    /** @private. */
    hasDragColumn?: boolean;
    /** @private. */
    hasInfoColumn?: boolean;
    /** @private. */
    onAutosizeColumn?: HeadAutosizeColumnHandler;
    /** @private. */
    onRequestMoveColumn?: HeadRequestMoveColumnHandler;
    /** @private. */
    onRequestResizeColumn?: HeadRequestResizeColumnHandler;
    /** @private. */
    onRequestToggleAllRows?: () => void;
    /** @private. */
    rowSelection?: 'all' | 'some' | 'none';
}
type HeadProps = ComponentProps<HeadPropsBase, 'thead'>;
declare const getCellWidths: (headEl: HTMLTableSectionElement | null) => number[];
declare function Head({ actions, actionsColumnWidth, cellMinWidth, children, elementRef, hasDragColumn, hasInfoColumn, onAutosizeColumn, onRequestMoveColumn, onRequestResizeColumn, onRequestToggleAllRows, rowSelection, ...otherProps }: HeadProps): React.JSX.Element;
declare namespace Head {
    var propTypes: {
        /** @private. */
        actions: PropTypes.Requireable<PropTypes.ReactNodeLike[]>;
        /** @private. */
        actionsColumnWidth: PropTypes.Requireable<number>;
        /** @private */
        cellMinWidth: PropTypes.Requireable<number>;
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        elementRef: PropTypes.Requireable<object>;
        /** @private. */
        hasDragColumn: PropTypes.Requireable<boolean>;
        /** @private. */
        hasInfoColumn: PropTypes.Requireable<boolean>;
        /** @private. */
        onAutosizeColumn: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. */
        onRequestMoveColumn: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. */
        onRequestResizeColumn: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. */
        onRequestToggleAllRows: PropTypes.Requireable<(...args: any[]) => any>;
        /** @private. */
        rowSelection: PropTypes.Requireable<string>;
    };
    var splunkUiType: string;
}
export default Head;
export { HeadAutosizeColumnHandler, HeadRequestMoveColumnHandler, HeadRequestResizeColumnHandler, getCellWidths, };
