import React from 'react';
import PropTypes from 'prop-types';
import { ComponentProps } from '../utils/types';
interface TransitionOpenPropsBase {
    animation?: 'slideFromTop' | 'slideFromRight' | 'slideFromBottom' | 'slideFromLeft' | 'expandHeight' | 'expandWidth' | 'none';
    animateOnMount?: boolean;
    children?: React.ReactNode;
    /** @private */
    className?: string;
    /**
     * A React ref which is set to the DOM element when the component mounts and null when it unmounts.
     */
    elementRef?: React.Ref<HTMLDivElement>;
    /** The `id` of the inner container. */
    id?: string;
    /** An additional className to inner container. */
    innerClassName?: string;
    innerStyle?: React.CSSProperties;
    onAnimationEnd?: () => void;
    /** Whether the component is currently open or not. */
    open?: boolean;
    /** An additional className to outer container. */
    outerClassName?: string;
    /** The `id` of the outer container. */
    outerId?: string;
    outerStyle?: React.CSSProperties;
    /**
     * When true, children are always rendered whether open or closed.
     */
    renderChildrenWhenCollapsed?: boolean;
    /**
     * Keep focus within `TransitionOpen` while open.
     */
    retainFocus?: boolean;
    /**
     * When true, the `TransitionOpen` automatically takes focus when 'open' changes to true.
     */
    takeFocus?: boolean;
}
type TransitionOpenProps = ComponentProps<TransitionOpenPropsBase, 'div'>;
declare function TransitionOpen({ animation, animateOnMount, children, className, elementRef, id, innerClassName, innerStyle, onAnimationEnd, open, outerClassName, outerId, outerStyle, renderChildrenWhenCollapsed, retainFocus, takeFocus: takeFocusProp, ...otherProps }: TransitionOpenProps): React.JSX.Element;
declare namespace TransitionOpen {
    var propTypes: {
        animation: PropTypes.Requireable<string>;
        animateOnMount: PropTypes.Requireable<boolean>;
        children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        elementRef: PropTypes.Requireable<object>;
        className: PropTypes.Requireable<string>;
        id: PropTypes.Requireable<string>;
        innerClassName: PropTypes.Requireable<string>;
        innerStyle: PropTypes.Requireable<object>;
        onAnimationEnd: PropTypes.Requireable<(...args: any[]) => any>;
        open: PropTypes.Requireable<boolean>;
        outerClassName: PropTypes.Requireable<string>;
        outerId: PropTypes.Requireable<string>;
        outerStyle: PropTypes.Requireable<object>;
        renderChildrenWhenCollapsed: PropTypes.Requireable<boolean>;
        retainFocus: PropTypes.Requireable<boolean>;
        takeFocus: PropTypes.Requireable<boolean>;
    };
}
export default TransitionOpen;
export { TransitionOpenPropsBase };
