/**
 * This is a private hook not intended for use outside @splunk/react-ui
 *
 * Handles "roving focus" for a group of elements inside a containing element.
 * Elements inside the element that "rovingFocusProps" are set on will act a single tab stop
 * with arrow keys moving focus between them.
 * See https://developer.mozilla.org/en-US/docs/Web/Accessibility/Keyboard-navigable_JavaScript_widgets#managing_focus_inside_groups
 *
 * ```
 * import React from 'react';
 * import useRovingFocus from '@splunk/react-ui/useRovingFocus';
 *
 * const rovingFocusProps = useRovingFocus();
 *
 * <div {...rovingFocusProps}>
 *     <button type="button">first</button>
 *     <button type="button">second</button>
 * </div>
 * ```
 */
declare function useRovingFocus(): {
    ref: (element: HTMLDivElement | null) => void;
    onBlur: (e: React.FocusEvent) => void;
    onFocus: (e: React.FocusEvent) => void;
    onKeyDown: (e: React.KeyboardEvent<HTMLDivElement>) => void;
};
export default useRovingFocus;
